Class: Aws::ConnectCases::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCases::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcases/client.rb,
sig/client.rbs
Overview
An API client for ConnectCases. To construct a client, you need to configure a :region and :credentials.
client = Aws::ConnectCases::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetCaseRuleResponseSuccess, _BatchGetFieldResponseSuccess, _BatchPutFieldOptionsResponseSuccess, _CreateCaseResponseSuccess, _CreateCaseRuleResponseSuccess, _CreateDomainResponseSuccess, _CreateFieldResponseSuccess, _CreateLayoutResponseSuccess, _CreateRelatedItemResponseSuccess, _CreateTemplateResponseSuccess, _DeleteCaseResponseSuccess, _DeleteCaseRuleResponseSuccess, _DeleteDomainResponseSuccess, _DeleteFieldResponseSuccess, _DeleteLayoutResponseSuccess, _DeleteRelatedItemResponseSuccess, _DeleteTemplateResponseSuccess, _GetCaseAuditEventsResponseSuccess, _GetCaseEventConfigurationResponseSuccess, _GetCaseResponseSuccess, _GetDomainResponseSuccess, _GetLayoutResponseSuccess, _GetTemplateResponseSuccess, _ListCaseRulesResponseSuccess, _ListCasesForContactResponseSuccess, _ListDomainsResponseSuccess, _ListFieldOptionsResponseSuccess, _ListFieldsResponseSuccess, _ListLayoutsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTemplatesResponseSuccess, _PutCaseEventConfigurationResponseSuccess, _SearchAllRelatedItemsResponseSuccess, _SearchCasesResponseSuccess, _SearchRelatedItemsResponseSuccess, _UpdateCaseResponseSuccess, _UpdateCaseRuleResponseSuccess, _UpdateFieldResponseSuccess, _UpdateLayoutResponseSuccess, _UpdateRelatedItemResponseSuccess, _UpdateTemplateResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_case_rule(params = {}) ⇒ Types::BatchGetCaseRuleResponse
Gets a batch of case rules.
-
#batch_get_field(params = {}) ⇒ Types::BatchGetFieldResponse
Returns the description for the list of fields in the request parameters.
-
#batch_put_field_options(params = {}) ⇒ Types::BatchPutFieldOptionsResponse
Creates and updates a set of field options for a single select field in a Cases domain.
-
#create_case(params = {}) ⇒ Types::CreateCaseResponse
If you provide a value for PerformedBy.UserArnyou must also have [connect:DescribeUser][1] permission on the User ARN resource that you provide. -
#create_case_rule(params = {}) ⇒ Types::CreateCaseRuleResponse
Creates a new case rule.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts.
-
#create_field(params = {}) ⇒ Types::CreateFieldResponse
Creates a field in the Cases domain.
-
#create_layout(params = {}) ⇒ Types::CreateLayoutResponse
Creates a layout in the Cases domain.
-
#create_related_item(params = {}) ⇒ Types::CreateRelatedItemResponse
Creates a related item (comments, tasks, and contacts) and associates it with a case.
-
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a template in the Cases domain.
-
#delete_case(params = {}) ⇒ Struct
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store.
-
#delete_case_rule(params = {}) ⇒ Struct
Deletes a case rule.
-
#delete_domain(params = {}) ⇒ Struct
Deletes a Cases domain.
-
#delete_field(params = {}) ⇒ Struct
Deletes a field from a cases template.
-
#delete_layout(params = {}) ⇒ Struct
Deletes a layout from a cases template.
-
#delete_related_item(params = {}) ⇒ Struct
Deletes the related item resource under a case.
-
#delete_template(params = {}) ⇒ Struct
Deletes a cases template.
-
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns information about a specific case if it exists.
-
#get_case_audit_events(params = {}) ⇒ Types::GetCaseAuditEventsResponse
Returns the audit history about a specific case if it exists.
-
#get_case_event_configuration(params = {}) ⇒ Types::GetCaseEventConfigurationResponse
Returns the case event publishing configuration.
-
#get_domain(params = {}) ⇒ Types::GetDomainResponse
Returns information about a specific domain if it exists.
-
#get_layout(params = {}) ⇒ Types::GetLayoutResponse
Returns the details for the requested layout.
-
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Returns the details for the requested template.
-
#list_case_rules(params = {}) ⇒ Types::ListCaseRulesResponse
Lists all case rules in a Cases domain.
-
#list_cases_for_contact(params = {}) ⇒ Types::ListCasesForContactResponse
Lists cases for a given contact.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all cases domains in the Amazon Web Services account.
-
#list_field_options(params = {}) ⇒ Types::ListFieldOptionsResponse
Lists all of the field options for a field identifier in the domain.
-
#list_fields(params = {}) ⇒ Types::ListFieldsResponse
Lists all fields in a Cases domain.
-
#list_layouts(params = {}) ⇒ Types::ListLayoutsResponse
Lists all layouts in the given cases domain.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
-
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists all of the templates in a Cases domain.
-
#put_case_event_configuration(params = {}) ⇒ Struct
Adds case event publishing configuration.
-
#search_all_related_items(params = {}) ⇒ Types::SearchAllRelatedItemsResponse
Searches for related items across all cases within a domain.
-
#search_cases(params = {}) ⇒ Types::SearchCasesResponse
Searches for cases within their associated Cases domain.
-
#search_related_items(params = {}) ⇒ Types::SearchRelatedItemsResponse
Searches for related items that are associated with a case.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
-
#update_case(params = {}) ⇒ Struct
If you provide a value for PerformedBy.UserArnyou must also have [connect:DescribeUser][1] permission on the User ARN resource that you provide. -
#update_case_rule(params = {}) ⇒ Struct
Updates a case rule.
-
#update_field(params = {}) ⇒ Struct
Updates the properties of an existing field.
-
#update_layout(params = {}) ⇒ Struct
Updates the attributes of an existing layout.
-
#update_related_item(params = {}) ⇒ Types::UpdateRelatedItemResponse
Updates the content of a related item associated with a case.
-
#update_template(params = {}) ⇒ Struct
Updates the attributes of an existing template.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectcases/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3648 3649 3650 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3648 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3651 3652 3653 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3651 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#batch_get_case_rule(params = {}) ⇒ Types::BatchGetCaseRuleResponse
Gets a batch of case rules. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
88 |
# File 'sig/client.rbs', line 88 def batch_get_case_rule: ( |
#batch_get_field(params = {}) ⇒ Types::BatchGetFieldResponse
Returns the description for the list of fields in the request parameters.
104 |
# File 'sig/client.rbs', line 104 def batch_get_field: ( |
#batch_put_field_options(params = {}) ⇒ Types::BatchPutFieldOptionsResponse
Creates and updates a set of field options for a single select field in a Cases domain.
119 |
# File 'sig/client.rbs', line 119 def batch_put_field_options: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3621 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCases') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcases' context[:gem_version] = '1.73.0' Seahorse::Client::Request.new(handlers, context) end |
#create_case(params = {}) ⇒ Types::CreateCaseResponse
PerformedBy.UserArn
you must also have
connect:DescribeUser permission on the User ARN resource that you
provide
Creates a case in the specified Cases domain. Case system and custom fields are taken as an array id/value pairs with a declared data types.
When creating a case from a template that has tag propagation configurations, the specified tags are automatically applied to the case.
The following fields are required when creating a case:
-
customer_id- You must provide the full customer profile ARN in this format:arn:aws:profile:your_AWS_Region:your_AWS_account ID:domains/your_profiles_domain_name/profiles/profile_ID -
title
138 |
# File 'sig/client.rbs', line 138 def create_case: ( |
#create_case_rule(params = {}) ⇒ Types::CreateCaseRuleResponse
Creates a new case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
159 |
# File 'sig/client.rbs', line 159 def create_case_rule: ( |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts. Each Amazon Connect instance can be associated with only one Cases domain.
This will not associate your connect instance to Cases domain. Instead, use the Amazon Connect CreateIntegrationAssociation API. You need specific IAM permissions to successfully associate the Cases domain. For more information, see Onboard to Cases.
174 |
# File 'sig/client.rbs', line 174 def create_domain: ( |
#create_field(params = {}) ⇒ Types::CreateFieldResponse
Creates a field in the Cases domain. This field is used to define the case object model (that is, defines what data can be captured on cases) in a Cases domain.
185 |
# File 'sig/client.rbs', line 185 def create_field: ( |
#create_layout(params = {}) ⇒ Types::CreateLayoutResponse
Creates a layout in the Cases domain. Layouts define the following configuration in the top section and More Info tab of the Cases user interface:
-
Fields to display to the users
-
Field ordering
204 |
# File 'sig/client.rbs', line 204 def create_layout: ( |
#create_related_item(params = {}) ⇒ Types::CreateRelatedItemResponse
Creates a related item (comments, tasks, and contacts) and associates it with a case.
There's a quota for the number of fields allowed in a Custom type related item. See Amazon Connect Cases quotas.
Use cases
Following are examples of related items that you may want to associate with a case:
-
Related contacts, such as calls, chats, emails tasks
-
Comments, for agent notes
-
SLAs, to capture target resolution goals
-
Cases, to capture related Amazon Connect Cases
-
Files, such as policy documentation or customer-provided attachments
-
Custom related items, which provide flexibility for you to define related items that such as bookings, orders, products, notices, and more
Important things to know
-
If you are associating a contact to a case by passing in
Contactfor atype, you must have DescribeContact permission on the ARN of the contact that you provide incontent.contact.contactArn. -
A Related Item is a resource that is associated with a case. It may or may not have an external identifier linking it to an external resource (for example, a
contactArn). All Related Items have their own internal identifier, therelatedItemArn. Examples of related items includecommentsandcontacts. -
If you provide a value for
performedBy.userArnyou must also have DescribeUser permission on the ARN of the user that you provide. -
The
typefield is reserved for internal use only.
Endpoints: See Amazon Connect endpoints and quotas.
217 |
# File 'sig/client.rbs', line 217 def create_related_item: ( |
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a template in the Cases domain. This template is used to define the case object model (that is, to define what data can be captured on cases) in a Cases domain. A template must have a unique name within a domain, and it must reference existing field IDs and layout IDs. Additionally, multiple fields with same IDs are not allowed within the same Template. A template can be either Active or Inactive, as indicated by its status. Inactive templates cannot be used to create cases.
Other template APIs are:
265 |
# File 'sig/client.rbs', line 265 def create_template: ( |
#delete_case(params = {}) ⇒ Struct
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store. After a successful deletion, you cannot:
-
Retrieve related items
-
Access audit history
-
Perform any operations that require the CaseID
This action is irreversible. After you delete a case, you cannot recover its data.
297 |
# File 'sig/client.rbs', line 297 def delete_case: ( |
#delete_case_rule(params = {}) ⇒ Struct
Deletes a case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
307 |
# File 'sig/client.rbs', line 307 def delete_case_rule: ( |
#delete_domain(params = {}) ⇒ Struct
Deletes a Cases domain.
317 |
# File 'sig/client.rbs', line 317 def delete_domain: ( |
#delete_field(params = {}) ⇒ Struct
Deletes a field from a cases template.
After a field is deleted:
-
You can still retrieve the field by calling
BatchGetField. -
You cannot update a deleted field by calling
UpdateField; it throws aValidationException. -
Deleted fields are not included in the
ListFieldsresponse. -
Calling
CreateCasewith a deleted field throws aValidationExceptiondenoting which field identifiers in the request have been deleted. -
Calling
GetCasewith a deleted field identifier returns the deleted field's value if one exists. -
Calling
UpdateCasewith a deleted field ID throws aValidationExceptionif the case does not already contain a value for the deleted field. Otherwise it succeeds, allowing you to update or remove (usingemptyValue: {}) the field's value from the case. -
GetTemplatedoes not return field IDs for deleted fields. -
GetLayoutdoes not return field IDs for deleted fields. -
Calling
SearchCaseswith the deleted field ID as a filter returns any cases that have a value for the deleted field that matches the filter criteria. -
Calling
SearchCaseswith asearchTermvalue that matches a deleted field's value on a case returns the case in the response. -
Calling
BatchPutFieldOptionswith a deleted field ID throw aValidationException. -
Calling
GetCaseEventConfigurationdoes not return field IDs for deleted fields.
326 |
# File 'sig/client.rbs', line 326 def delete_field: ( |
#delete_layout(params = {}) ⇒ Struct
Deletes a layout from a cases template. You can delete up to 100 layouts per domain.
After a layout is deleted:
-
You can still retrieve the layout by calling
GetLayout. -
You cannot update a deleted layout by calling
UpdateLayout; it throws aValidationException. -
Deleted layouts are not included in the
ListLayoutsresponse.
336 |
# File 'sig/client.rbs', line 336 def delete_layout: ( |
#delete_related_item(params = {}) ⇒ Struct
Deletes the related item resource under a case.
346 |
# File 'sig/client.rbs', line 346 def delete_related_item: ( |
#delete_template(params = {}) ⇒ Struct
Deletes a cases template. You can delete up to 100 templates per domain.
After a cases template is deleted:
-
You can still retrieve the template by calling
GetTemplate. -
You cannot update the template.
-
You cannot create a case by using the deleted template.
-
Deleted templates are not included in the
ListTemplatesresponse.
357 |
# File 'sig/client.rbs', line 357 def delete_template: ( |
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns information about a specific case if it exists.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
371 |
# File 'sig/client.rbs', line 371 def get_case: ( |
#get_case_audit_events(params = {}) ⇒ Types::GetCaseAuditEventsResponse
Returns the audit history about a specific case if it exists.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
389 |
# File 'sig/client.rbs', line 389 def get_case_audit_events: ( |
#get_case_event_configuration(params = {}) ⇒ Types::GetCaseEventConfigurationResponse
Returns the case event publishing configuration.
402 |
# File 'sig/client.rbs', line 402 def get_case_event_configuration: ( |
#get_domain(params = {}) ⇒ Types::GetDomainResponse
Returns information about a specific domain if it exists.
417 |
# File 'sig/client.rbs', line 417 def get_domain: ( |
#get_layout(params = {}) ⇒ Types::GetLayoutResponse
Returns the details for the requested layout.
434 |
# File 'sig/client.rbs', line 434 def get_layout: ( |
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Returns the details for the requested template. Other template APIs are:
457 |
# File 'sig/client.rbs', line 457 def get_template: ( |
#list_case_rules(params = {}) ⇒ Types::ListCaseRulesResponse
Lists all case rules in a Cases domain. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
469 |
# File 'sig/client.rbs', line 469 def list_case_rules: ( |
#list_cases_for_contact(params = {}) ⇒ Types::ListCasesForContactResponse
Lists cases for a given contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
482 |
# File 'sig/client.rbs', line 482 def list_cases_for_contact: ( |
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all cases domains in the Amazon Web Services account. Each list item is a condensed summary object of the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
496 |
# File 'sig/client.rbs', line 496 def list_domains: ( |
#list_field_options(params = {}) ⇒ Types::ListFieldOptionsResponse
Lists all of the field options for a field identifier in the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
508 |
# File 'sig/client.rbs', line 508 def list_field_options: ( |
#list_fields(params = {}) ⇒ Types::ListFieldsResponse
Lists all fields in a Cases domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
523 |
# File 'sig/client.rbs', line 523 def list_fields: ( |
#list_layouts(params = {}) ⇒ Types::ListLayoutsResponse
Lists all layouts in the given cases domain. Each list item is a condensed summary object of the layout.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
536 |
# File 'sig/client.rbs', line 536 def list_layouts: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
548 |
# File 'sig/client.rbs', line 548 def list_tags_for_resource: ( |
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists all of the templates in a Cases domain. Each list item is a condensed summary object of the template.
Other template APIs are:
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
559 |
# File 'sig/client.rbs', line 559 def list_templates: ( |
#put_case_event_configuration(params = {}) ⇒ Struct
Adds case event publishing configuration. For a complete list of fields you can add to the event message, see Create case fields in the Amazon Connect Administrator Guide
571 |
# File 'sig/client.rbs', line 571 def put_case_event_configuration: ( |
#search_all_related_items(params = {}) ⇒ Types::SearchAllRelatedItemsResponse
Searches for related items across all cases within a domain. This is a global search operation that returns related items from multiple cases, unlike the case-specific SearchRelatedItems API.
Use cases
Following are common uses cases for this API:
-
Find cases with similar issues across the domain. For example, search for all cases containing comments about "product defect" to identify patterns and existing solutions.
-
Locate all cases associated with specific contacts or orders. For example, find all cases linked to a contactArn to understand the complete customer journey.
-
Monitor SLA compliance across cases. For example, search for all cases with "Active" SLA status to prioritize remediation efforts.
Important things to know
-
This API returns case identifiers, not complete case objects. To retrieve full case details, you must make additional calls to the GetCase API for each returned case ID.
-
This API searches across related items content, not case fields. Use the SearchCases API to search within case field values.
Endpoints: See Amazon Connect endpoints and quotas.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
597 |
# File 'sig/client.rbs', line 597 def search_all_related_items: ( |
#search_cases(params = {}) ⇒ Types::SearchCasesResponse
Searches for cases within their associated Cases domain. Search results are returned as a paginated list of abridged case documents.
customer_id you must provide the full customer profile ARN in
this format: arn:aws:profile:your AWS Region:your AWS account ID:domains/profiles domain name/profiles/profile ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
620 |
# File 'sig/client.rbs', line 620 def search_cases: ( |
#search_related_items(params = {}) ⇒ Types::SearchRelatedItemsResponse
Searches for related items that are associated with a case.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
646 |
# File 'sig/client.rbs', line 646 def search_related_items: ( |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
658 |
# File 'sig/client.rbs', line 658 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
665 |
# File 'sig/client.rbs', line 665 def untag_resource: ( |
#update_case(params = {}) ⇒ Struct
PerformedBy.UserArn
you must also have
connect:DescribeUser permission on the User ARN resource that you
provide
Updates the values of fields on a case. Fields to be updated are
received as an array of id/value pairs identical to the CreateCase
input .
If the action is successful, the service sends back an HTTP 200 response with an empty HTTP body.
675 |
# File 'sig/client.rbs', line 675 def update_case: ( |
#update_case_rule(params = {}) ⇒ Struct
Updates a case rule. In the Amazon Connect admin website, case rules are known as case field conditions. For more information about case field conditions, see Add case field conditions to a case template.
692 |
# File 'sig/client.rbs', line 692 def update_case_rule: ( |
#update_field(params = {}) ⇒ Struct
Updates the properties of an existing field.
705 |
# File 'sig/client.rbs', line 705 def update_field: ( |
#update_layout(params = {}) ⇒ Struct
Updates the attributes of an existing layout.
If the action is successful, the service sends back an HTTP 200 response with an empty HTTP body.
A ValidationException is returned when you add non-existent
fieldIds to a layout.
722 |
# File 'sig/client.rbs', line 722 def update_layout: ( |
#update_related_item(params = {}) ⇒ Types::UpdateRelatedItemResponse
Updates the content of a related item associated with a case. The following related item types are supported:
-
Comment - Update the text content of an existing comment
-
Custom - Update the fields of a custom related item. You can add, modify, and remove fields from a custom related item. There's a quota for the number of fields allowed in a Custom type related item. See Amazon Connect Cases quotas.
Important things to know
-
When updating a Custom related item, all existing and new fields, and their associated values should be included in the request. Fields not included as part of this request will be removed.
-
If you provide a value for
performedBy.userArnyou must also have DescribeUser permission on the ARN of the user that you provide. -
System case fields cannot be used in a custom related item.
Endpoints: See Amazon Connect endpoints and quotas.
742 |
# File 'sig/client.rbs', line 742 def update_related_item: ( |
#update_template(params = {}) ⇒ Struct
Updates the attributes of an existing template. The template
attributes that can be modified include name, description,
layoutConfiguration, requiredFields, and status. At least one of
these attributes must not be null. If a null value is provided for a
given attribute, that attribute is ignored and its current value is
preserved.
Other template APIs are:
768 |
# File 'sig/client.rbs', line 768 def update_template: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3641 3642 3643 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3641 def waiter_names [] end |