Module: Aws::ConnectCases::Types
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Defined Under Namespace
Classes: AccessDeniedException, AuditEvent, AuditEventField, AuditEventFieldValueUnion, AuditEventPerformedBy, BasicLayout, BatchGetCaseRuleRequest, BatchGetCaseRuleResponse, BatchGetFieldRequest, BatchGetFieldResponse, BatchPutFieldOptionsRequest, BatchPutFieldOptionsResponse, BooleanCondition, BooleanOperands, CaseEventIncludedData, CaseFilter, CaseRuleDetails, CaseRuleError, CaseRuleIdentifier, CaseRuleSummary, CaseSummary, CommentContent, CommentFilter, CommentUpdateContent, CompoundCondition, ConflictException, ConnectCaseContent, ConnectCaseFilter, ConnectCaseInputContent, Contact, ContactContent, ContactFilter, CreateCaseRequest, CreateCaseResponse, CreateCaseRuleRequest, CreateCaseRuleResponse, CreateDomainRequest, CreateDomainResponse, CreateFieldRequest, CreateFieldResponse, CreateLayoutRequest, CreateLayoutResponse, CreateRelatedItemRequest, CreateRelatedItemResponse, CreateTemplateRequest, CreateTemplateResponse, CustomContent, CustomFieldsFilter, CustomFilter, CustomInputContent, CustomUpdateContent, DeleteCaseRequest, DeleteCaseResponse, DeleteCaseRuleRequest, DeleteCaseRuleResponse, DeleteDomainRequest, DeleteDomainResponse, DeleteFieldRequest, DeleteFieldResponse, DeleteLayoutRequest, DeleteLayoutResponse, DeleteRelatedItemRequest, DeleteRelatedItemResponse, DeleteTemplateRequest, DeleteTemplateResponse, DomainSummary, EmptyFieldValue, EmptyOperandValue, EventBridgeConfiguration, EventIncludedData, FieldAttributes, FieldError, FieldFilter, FieldGroup, FieldIdentifier, FieldItem, FieldOption, FieldOptionError, FieldOptionsCaseRule, FieldSummary, FieldValue, FieldValueUnion, FileContent, FileFilter, GetCaseAuditEventsRequest, GetCaseAuditEventsResponse, GetCaseEventConfigurationRequest, GetCaseEventConfigurationResponse, GetCaseRequest, GetCaseResponse, GetCaseRuleResponse, GetDomainRequest, GetDomainResponse, GetFieldResponse, GetLayoutRequest, GetLayoutResponse, GetTemplateRequest, GetTemplateResponse, HiddenCaseRule, InternalServerException, LayoutConfiguration, LayoutContent, LayoutSections, LayoutSummary, ListCaseRulesRequest, ListCaseRulesResponse, ListCasesForContactRequest, ListCasesForContactResponse, ListDomainsRequest, ListDomainsResponse, ListFieldOptionsRequest, ListFieldOptionsResponse, ListFieldsRequest, ListFieldsResponse, ListLayoutsRequest, ListLayoutsResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, ListTemplatesRequest, ListTemplatesResponse, OperandOne, OperandTwo, ParentChildFieldOptionsMapping, PutCaseEventConfigurationRequest, PutCaseEventConfigurationResponse, RelatedItemContent, RelatedItemEventIncludedData, RelatedItemInputContent, RelatedItemTypeFilter, RelatedItemUpdateContent, RequiredCaseRule, RequiredField, ResourceNotFoundException, SearchAllRelatedItemsRequest, SearchAllRelatedItemsResponse, SearchAllRelatedItemsResponseItem, SearchAllRelatedItemsSort, SearchCasesRequest, SearchCasesResponse, SearchCasesResponseItem, SearchRelatedItemsRequest, SearchRelatedItemsResponse, SearchRelatedItemsResponseItem, Section, ServiceQuotaExceededException, SlaConfiguration, SlaContent, SlaFilter, SlaInputConfiguration, SlaInputContent, Sort, TagFilter, TagPropagationConfiguration, TagResourceRequest, TagValue, TemplateRule, TemplateSummary, TextAttributes, ThrottlingException, UntagResourceRequest, UpdateCaseRequest, UpdateCaseResponse, UpdateCaseRuleRequest, UpdateCaseRuleResponse, UpdateFieldRequest, UpdateFieldResponse, UpdateLayoutRequest, UpdateLayoutResponse, UpdateRelatedItemRequest, UpdateRelatedItemResponse, UpdateTemplateRequest, UpdateTemplateResponse, UserUnion, ValidationException
Instance Attribute Summary collapse
-
#and_all ⇒ Array<Types::CustomFieldsFilter>
Provides “and all” filtering.
-
#basic ⇒ Types::BasicLayout
Content specific to ‘BasicLayout` type.
-
#boolean_value ⇒ Boolean
Boolean value type.
-
#comment ⇒ Types::CommentUpdateContent
Represents the updated content of a ‘Comment` related item.
-
#connect_case ⇒ Types::ConnectCaseFilter
Represents the Amazon Connect case to be created as a related item.
-
#contact ⇒ Types::ContactFilter
A filter for related items of type ‘Contact`.
-
#contains ⇒ Types::FieldValue
Object containing field identifier and value information.
-
#custom ⇒ Types::CustomUpdateContent
Represents the updated content of a ‘Custom` related item.
-
#custom_entity ⇒ String
Any provided entity.
-
#double_value ⇒ Float
Double value type.
-
#empty_value ⇒ Types::EmptyOperandValue
Empty value type.
-
#equal_to ⇒ Types::TagValue
Object containing tag key and value information.
-
#field ⇒ Types::FieldFilter
A filter for fields.
-
#field_group ⇒ Types::FieldGroup
Consists of a group of fields and associated properties.
-
#field_id ⇒ String
The field ID that this operand should take the value of.
-
#field_options ⇒ Types::FieldOptionsCaseRule
Which options are available in a child field based on the selected value in a parent field.
-
#file ⇒ Types::FileFilter
A filter for related items of this type of ‘File`.
-
#greater_than ⇒ Types::FieldValue
Object containing field identifier and value information.
-
#greater_than_or_equal_to ⇒ Types::FieldValue
Object containing field identifier and value information.
-
#hidden ⇒ Types::HiddenCaseRule
Whether a field is visible, based on values in other fields.
-
#less_than ⇒ Types::FieldValue
Object containing field identifier and value information.
-
#less_than_or_equal_to ⇒ Types::FieldValue
Object containing field identifier and value information.
-
#not ⇒ Types::CustomFieldsFilter
Excludes items matching the filter.
-
#not_equal_to ⇒ Types::BooleanOperands
Tests that operandOne is not equal to operandTwo.
-
#or_all ⇒ Array<Types::CustomFieldsFilter>
Provides “or all” filtering.
-
#required ⇒ Types::RequiredCaseRule
Required rule type, used to indicate whether a field is required.
-
#sla ⇒ Types::SlaFilter
Filter for related items of type ‘SLA`.
-
#sla_input_configuration ⇒ Types::SlaInputConfiguration
Represents an input SLA configuration.
-
#string_value ⇒ String
String value type.
-
#tag ⇒ Types::TagFilter
A list of tags to filter on.
-
#text ⇒ Types::TextAttributes
Field attributes for Text field type.
-
#user_arn ⇒ String
Represents the Amazon Connect ARN of the user.
-
#user_arn_value ⇒ String
Represents the user that performed the audit.
Instance Attribute Details
#and_all ⇒ Array<Types::CustomFieldsFilter>
Provides “and all” filtering.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/aws-sdk-connectcases/types.rb', line 325 class BooleanCondition < Struct.new( :equal_to, :not_equal_to, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < BooleanCondition; end class NotEqualTo < BooleanCondition; end class AndAll < BooleanCondition; end class OrAll < BooleanCondition; end class Unknown < BooleanCondition; end end |
#basic ⇒ Types::BasicLayout
Content specific to ‘BasicLayout` type. It configures fields in the top panel and More Info tab of Cases user interface.
2362 2363 2364 2365 2366 2367 2368 2369 2370 2371 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2362 class LayoutContent < Struct.new( :basic, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Basic < LayoutContent; end class Unknown < LayoutContent; end end |
#boolean_value ⇒ Boolean
Boolean value type.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-connectcases/types.rb', line 127 class AuditEventFieldValueUnion < Struct.new( :string_value, :double_value, :boolean_value, :empty_value, :user_arn_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AuditEventFieldValueUnion; end class DoubleValue < AuditEventFieldValueUnion; end class BooleanValue < AuditEventFieldValueUnion; end class EmptyValue < AuditEventFieldValueUnion; end class UserArnValue < AuditEventFieldValueUnion; end class Unknown < AuditEventFieldValueUnion; end end |
#comment ⇒ Types::CommentUpdateContent
Represents the updated content of a ‘Comment` related item.
2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2897 class RelatedItemContent < Struct.new( :contact, :comment, :file, :sla, :connect_case, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Contact < RelatedItemContent; end class Comment < RelatedItemContent; end class File < RelatedItemContent; end class Sla < RelatedItemContent; end class ConnectCase < RelatedItemContent; end class Custom < RelatedItemContent; end class Unknown < RelatedItemContent; end end |
#connect_case ⇒ Types::ConnectCaseFilter
Represents the Amazon Connect case to be created as a related item.
2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2897 class RelatedItemContent < Struct.new( :contact, :comment, :file, :sla, :connect_case, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Contact < RelatedItemContent; end class Comment < RelatedItemContent; end class File < RelatedItemContent; end class Sla < RelatedItemContent; end class ConnectCase < RelatedItemContent; end class Custom < RelatedItemContent; end class Unknown < RelatedItemContent; end end |
#contact ⇒ Types::ContactFilter
A filter for related items of type ‘Contact`.
2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2897 class RelatedItemContent < Struct.new( :contact, :comment, :file, :sla, :connect_case, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Contact < RelatedItemContent; end class Comment < RelatedItemContent; end class File < RelatedItemContent; end class Sla < RelatedItemContent; end class ConnectCase < RelatedItemContent; end class Custom < RelatedItemContent; end class Unknown < RelatedItemContent; end end |
#contains ⇒ Types::FieldValue
Object containing field identifier and value information.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1538 class FieldFilter < Struct.new( :equal_to, :contains, :greater_than, :greater_than_or_equal_to, :less_than, :less_than_or_equal_to, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < FieldFilter; end class Contains < FieldFilter; end class GreaterThan < FieldFilter; end class GreaterThanOrEqualTo < FieldFilter; end class LessThan < FieldFilter; end class LessThanOrEqualTo < FieldFilter; end class Unknown < FieldFilter; end end |
#custom ⇒ Types::CustomUpdateContent
Represents the updated content of a ‘Custom` related item.
2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2897 class RelatedItemContent < Struct.new( :contact, :comment, :file, :sla, :connect_case, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Contact < RelatedItemContent; end class Comment < RelatedItemContent; end class File < RelatedItemContent; end class Sla < RelatedItemContent; end class ConnectCase < RelatedItemContent; end class Custom < RelatedItemContent; end class Unknown < RelatedItemContent; end end |
#custom_entity ⇒ String
Any provided entity.
4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-connectcases/types.rb', line 4136 class UserUnion < Struct.new( :user_arn, :custom_entity, :unknown) SENSITIVE = [:custom_entity] include Aws::Structure include Aws::Structure::Union class UserArn < UserUnion; end class CustomEntity < UserUnion; end class Unknown < UserUnion; end end |
#double_value ⇒ Float
Double value type.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-connectcases/types.rb', line 127 class AuditEventFieldValueUnion < Struct.new( :string_value, :double_value, :boolean_value, :empty_value, :user_arn_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AuditEventFieldValueUnion; end class DoubleValue < AuditEventFieldValueUnion; end class BooleanValue < AuditEventFieldValueUnion; end class EmptyValue < AuditEventFieldValueUnion; end class UserArnValue < AuditEventFieldValueUnion; end class Unknown < AuditEventFieldValueUnion; end end |
#empty_value ⇒ Types::EmptyOperandValue
Empty value type.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-connectcases/types.rb', line 127 class AuditEventFieldValueUnion < Struct.new( :string_value, :double_value, :boolean_value, :empty_value, :user_arn_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AuditEventFieldValueUnion; end class DoubleValue < AuditEventFieldValueUnion; end class BooleanValue < AuditEventFieldValueUnion; end class EmptyValue < AuditEventFieldValueUnion; end class UserArnValue < AuditEventFieldValueUnion; end class Unknown < AuditEventFieldValueUnion; end end |
#equal_to ⇒ Types::TagValue
Object containing tag key and value information.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/aws-sdk-connectcases/types.rb', line 325 class BooleanCondition < Struct.new( :equal_to, :not_equal_to, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < BooleanCondition; end class NotEqualTo < BooleanCondition; end class AndAll < BooleanCondition; end class OrAll < BooleanCondition; end class Unknown < BooleanCondition; end end |
#field ⇒ Types::FieldFilter
A filter for fields. Only one value can be provided.
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/aws-sdk-connectcases/types.rb', line 413 class CaseFilter < Struct.new( :field, :not, :tag, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Field < CaseFilter; end class Not < CaseFilter; end class Tag < CaseFilter; end class AndAll < CaseFilter; end class OrAll < CaseFilter; end class Unknown < CaseFilter; end end |
#field_group ⇒ Types::FieldGroup
Consists of a group of fields and associated properties.
3468 3469 3470 3471 3472 3473 3474 3475 3476 3477 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3468 class Section < Struct.new( :field_group, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class FieldGroup < Section; end class Unknown < Section; end end |
#field_id ⇒ String
The field ID that this operand should take the value of.
2766 2767 2768 2769 2770 2771 2772 2773 2774 2775 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2766 class OperandOne < Struct.new( :field_id, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class FieldId < OperandOne; end class Unknown < OperandOne; end end |
#field_options ⇒ Types::FieldOptionsCaseRule
Which options are available in a child field based on the selected value in a parent field.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/aws-sdk-connectcases/types.rb', line 460 class CaseRuleDetails < Struct.new( :required, :field_options, :hidden, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Required < CaseRuleDetails; end class FieldOptions < CaseRuleDetails; end class Hidden < CaseRuleDetails; end class Unknown < CaseRuleDetails; end end |
#file ⇒ Types::FileFilter
A filter for related items of this type of ‘File`.
2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2897 class RelatedItemContent < Struct.new( :contact, :comment, :file, :sla, :connect_case, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Contact < RelatedItemContent; end class Comment < RelatedItemContent; end class File < RelatedItemContent; end class Sla < RelatedItemContent; end class ConnectCase < RelatedItemContent; end class Custom < RelatedItemContent; end class Unknown < RelatedItemContent; end end |
#greater_than ⇒ Types::FieldValue
Object containing field identifier and value information.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1538 class FieldFilter < Struct.new( :equal_to, :contains, :greater_than, :greater_than_or_equal_to, :less_than, :less_than_or_equal_to, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < FieldFilter; end class Contains < FieldFilter; end class GreaterThan < FieldFilter; end class GreaterThanOrEqualTo < FieldFilter; end class LessThan < FieldFilter; end class LessThanOrEqualTo < FieldFilter; end class Unknown < FieldFilter; end end |
#greater_than_or_equal_to ⇒ Types::FieldValue
Object containing field identifier and value information.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1538 class FieldFilter < Struct.new( :equal_to, :contains, :greater_than, :greater_than_or_equal_to, :less_than, :less_than_or_equal_to, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < FieldFilter; end class Contains < FieldFilter; end class GreaterThan < FieldFilter; end class GreaterThanOrEqualTo < FieldFilter; end class LessThan < FieldFilter; end class LessThanOrEqualTo < FieldFilter; end class Unknown < FieldFilter; end end |
#hidden ⇒ Types::HiddenCaseRule
Whether a field is visible, based on values in other fields.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/aws-sdk-connectcases/types.rb', line 460 class CaseRuleDetails < Struct.new( :required, :field_options, :hidden, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Required < CaseRuleDetails; end class FieldOptions < CaseRuleDetails; end class Hidden < CaseRuleDetails; end class Unknown < CaseRuleDetails; end end |
#less_than ⇒ Types::FieldValue
Object containing field identifier and value information.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1538 class FieldFilter < Struct.new( :equal_to, :contains, :greater_than, :greater_than_or_equal_to, :less_than, :less_than_or_equal_to, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < FieldFilter; end class Contains < FieldFilter; end class GreaterThan < FieldFilter; end class GreaterThanOrEqualTo < FieldFilter; end class LessThan < FieldFilter; end class LessThanOrEqualTo < FieldFilter; end class Unknown < FieldFilter; end end |
#less_than_or_equal_to ⇒ Types::FieldValue
Object containing field identifier and value information.
1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1538 class FieldFilter < Struct.new( :equal_to, :contains, :greater_than, :greater_than_or_equal_to, :less_than, :less_than_or_equal_to, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < FieldFilter; end class Contains < FieldFilter; end class GreaterThan < FieldFilter; end class GreaterThanOrEqualTo < FieldFilter; end class LessThan < FieldFilter; end class LessThanOrEqualTo < FieldFilter; end class Unknown < FieldFilter; end end |
#not ⇒ Types::CustomFieldsFilter
Excludes items matching the filter.
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/aws-sdk-connectcases/types.rb', line 413 class CaseFilter < Struct.new( :field, :not, :tag, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Field < CaseFilter; end class Not < CaseFilter; end class Tag < CaseFilter; end class AndAll < CaseFilter; end class OrAll < CaseFilter; end class Unknown < CaseFilter; end end |
#not_equal_to ⇒ Types::BooleanOperands
Tests that operandOne is not equal to operandTwo.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/aws-sdk-connectcases/types.rb', line 325 class BooleanCondition < Struct.new( :equal_to, :not_equal_to, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < BooleanCondition; end class NotEqualTo < BooleanCondition; end class AndAll < BooleanCondition; end class OrAll < BooleanCondition; end class Unknown < BooleanCondition; end end |
#or_all ⇒ Array<Types::CustomFieldsFilter>
Provides “or all” filtering.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/aws-sdk-connectcases/types.rb', line 325 class BooleanCondition < Struct.new( :equal_to, :not_equal_to, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EqualTo < BooleanCondition; end class NotEqualTo < BooleanCondition; end class AndAll < BooleanCondition; end class OrAll < BooleanCondition; end class Unknown < BooleanCondition; end end |
#required ⇒ Types::RequiredCaseRule
Required rule type, used to indicate whether a field is required.
460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/aws-sdk-connectcases/types.rb', line 460 class CaseRuleDetails < Struct.new( :required, :field_options, :hidden, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Required < CaseRuleDetails; end class FieldOptions < CaseRuleDetails; end class Hidden < CaseRuleDetails; end class Unknown < CaseRuleDetails; end end |
#sla ⇒ Types::SlaFilter
Filter for related items of type ‘SLA`.
2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2897 class RelatedItemContent < Struct.new( :contact, :comment, :file, :sla, :connect_case, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Contact < RelatedItemContent; end class Comment < RelatedItemContent; end class File < RelatedItemContent; end class Sla < RelatedItemContent; end class ConnectCase < RelatedItemContent; end class Custom < RelatedItemContent; end class Unknown < RelatedItemContent; end end |
#sla_input_configuration ⇒ Types::SlaInputConfiguration
Represents an input SLA configuration.
3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3622 class SlaInputContent < Struct.new( :sla_input_configuration, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class SlaInputConfiguration < SlaInputContent; end class Unknown < SlaInputContent; end end |
#string_value ⇒ String
String value type.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-connectcases/types.rb', line 127 class AuditEventFieldValueUnion < Struct.new( :string_value, :double_value, :boolean_value, :empty_value, :user_arn_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AuditEventFieldValueUnion; end class DoubleValue < AuditEventFieldValueUnion; end class BooleanValue < AuditEventFieldValueUnion; end class EmptyValue < AuditEventFieldValueUnion; end class UserArnValue < AuditEventFieldValueUnion; end class Unknown < AuditEventFieldValueUnion; end end |
#tag ⇒ Types::TagFilter
A list of tags to filter on.
413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/aws-sdk-connectcases/types.rb', line 413 class CaseFilter < Struct.new( :field, :not, :tag, :and_all, :or_all, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Field < CaseFilter; end class Not < CaseFilter; end class Tag < CaseFilter; end class AndAll < CaseFilter; end class OrAll < CaseFilter; end class Unknown < CaseFilter; end end |
#text ⇒ Types::TextAttributes
Field attributes for Text field type.
1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1473 class FieldAttributes < Struct.new( :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < FieldAttributes; end class Unknown < FieldAttributes; end end |
#user_arn ⇒ String
Represents the Amazon Connect ARN of the user.
4136 4137 4138 4139 4140 4141 4142 4143 4144 4145 4146 4147 |
# File 'lib/aws-sdk-connectcases/types.rb', line 4136 class UserUnion < Struct.new( :user_arn, :custom_entity, :unknown) SENSITIVE = [:custom_entity] include Aws::Structure include Aws::Structure::Union class UserArn < UserUnion; end class CustomEntity < UserUnion; end class Unknown < UserUnion; end end |
#user_arn_value ⇒ String
Represents the user that performed the audit.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/aws-sdk-connectcases/types.rb', line 127 class AuditEventFieldValueUnion < Struct.new( :string_value, :double_value, :boolean_value, :empty_value, :user_arn_value, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class StringValue < AuditEventFieldValueUnion; end class DoubleValue < AuditEventFieldValueUnion; end class BooleanValue < AuditEventFieldValueUnion; end class EmptyValue < AuditEventFieldValueUnion; end class UserArnValue < AuditEventFieldValueUnion; end class Unknown < AuditEventFieldValueUnion; end end |