Class: Aws::ConnectCases::Types::BooleanCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Note:

BooleanCondition is a union - when making an API calls you must set exactly one of the members.

Note:

BooleanCondition is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of BooleanCondition corresponding to the set member.

Boolean condition for a rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].

[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html

Direct Known Subclasses

AndAll, EqualTo, NotEqualTo, OrAll, Unknown

Defined Under Namespace

Classes: AndAll, EqualTo, NotEqualTo, OrAll, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#and_allTypes::CompoundCondition

Combines multiple conditions with AND operator. All conditions must be true for the compound condition to be true.



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/aws-sdk-connectcases/types.rb', line 321

class BooleanCondition < Struct.new(
  :equal_to,
  :not_equal_to,
  :and_all,
  :or_all,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EqualTo < BooleanCondition; end
  class NotEqualTo < BooleanCondition; end
  class AndAll < BooleanCondition; end
  class OrAll < BooleanCondition; end
  class Unknown < BooleanCondition; end
end

#equal_toTypes::BooleanOperands

Tests that operandOne is equal to operandTwo.



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/aws-sdk-connectcases/types.rb', line 321

class BooleanCondition < Struct.new(
  :equal_to,
  :not_equal_to,
  :and_all,
  :or_all,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EqualTo < BooleanCondition; end
  class NotEqualTo < BooleanCondition; end
  class AndAll < BooleanCondition; end
  class OrAll < BooleanCondition; end
  class Unknown < BooleanCondition; end
end

#not_equal_toTypes::BooleanOperands

Tests that operandOne is not equal to operandTwo.



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/aws-sdk-connectcases/types.rb', line 321

class BooleanCondition < Struct.new(
  :equal_to,
  :not_equal_to,
  :and_all,
  :or_all,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EqualTo < BooleanCondition; end
  class NotEqualTo < BooleanCondition; end
  class AndAll < BooleanCondition; end
  class OrAll < BooleanCondition; end
  class Unknown < BooleanCondition; end
end

#or_allTypes::CompoundCondition

Combines multiple conditions with OR operator. At least one condition must be true for the compound condition to be true.



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/aws-sdk-connectcases/types.rb', line 321

class BooleanCondition < Struct.new(
  :equal_to,
  :not_equal_to,
  :and_all,
  :or_all,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EqualTo < BooleanCondition; end
  class NotEqualTo < BooleanCondition; end
  class AndAll < BooleanCondition; end
  class OrAll < BooleanCondition; end
  class Unknown < BooleanCondition; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



321
322
323
# File 'lib/aws-sdk-connectcases/types.rb', line 321

def unknown
  @unknown
end