Class: Aws::ConnectCases::Types::CommentUpdateContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::CommentUpdateContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Represents the updated content of a ‘Comment` related item.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#body ⇒ String
Updated text in the body of a ‘Comment` on a case.
-
#content_type ⇒ String
Type of the text in the box of a ‘Comment` on a case.
Instance Attribute Details
#body ⇒ String
Updated text in the body of a ‘Comment` on a case.
619 620 621 622 623 624 |
# File 'lib/aws-sdk-connectcases/types.rb', line 619 class CommentUpdateContent < Struct.new( :body, :content_type) SENSITIVE = [] include Aws::Structure end |
#content_type ⇒ String
Type of the text in the box of a ‘Comment` on a case.
619 620 621 622 623 624 |
# File 'lib/aws-sdk-connectcases/types.rb', line 619 class CommentUpdateContent < Struct.new( :body, :content_type) SENSITIVE = [] include Aws::Structure end |