Class: Aws::ConnectCases::Types::CreateCaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. For more information about idempotency, see [Making retries safe with idempotent APIs].

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: aws.amazon.com/builders-library/making-retries-safe-with-idempotent-APIs/

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
# File 'lib/aws-sdk-connectcases/types.rb', line 780

class CreateCaseRequest < Struct.new(
  :domain_id,
  :template_id,
  :fields,
  :client_token,
  :performed_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#domain_idString

The unique identifier of the Cases domain.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
# File 'lib/aws-sdk-connectcases/types.rb', line 780

class CreateCaseRequest < Struct.new(
  :domain_id,
  :template_id,
  :fields,
  :client_token,
  :performed_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#fieldsArray<Types::FieldValue>

An array of objects with field ID (matching ListFields/DescribeField) and value union data.

Returns:



780
781
782
783
784
785
786
787
788
789
# File 'lib/aws-sdk-connectcases/types.rb', line 780

class CreateCaseRequest < Struct.new(
  :domain_id,
  :template_id,
  :fields,
  :client_token,
  :performed_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#performed_byTypes::UserUnion

Represents the entity that performed the action.

Returns:



780
781
782
783
784
785
786
787
788
789
# File 'lib/aws-sdk-connectcases/types.rb', line 780

class CreateCaseRequest < Struct.new(
  :domain_id,
  :template_id,
  :fields,
  :client_token,
  :performed_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

A map of of key-value pairs that represent tags on a resource. Tags are used to organize, track, or control access for this resource.

Returns:

  • (Hash<String,String>)


780
781
782
783
784
785
786
787
788
789
# File 'lib/aws-sdk-connectcases/types.rb', line 780

class CreateCaseRequest < Struct.new(
  :domain_id,
  :template_id,
  :fields,
  :client_token,
  :performed_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#template_idString

A unique identifier of a template.

Returns:

  • (String)


780
781
782
783
784
785
786
787
788
789
# File 'lib/aws-sdk-connectcases/types.rb', line 780

class CreateCaseRequest < Struct.new(
  :domain_id,
  :template_id,
  :fields,
  :client_token,
  :performed_by,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end