Class: Aws::ConnectCases::Types::CreateFieldRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::CreateFieldRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attributes ⇒ Types::FieldAttributes
Union of field attributes.
-
#description ⇒ String
The description of the field.
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#name ⇒ String
The name of the field.
-
#type ⇒ String
Defines the data type, some system constraints, and default display of the field.
Instance Attribute Details
#attributes ⇒ Types::FieldAttributes
Union of field attributes.
910 911 912 913 914 915 916 917 918 |
# File 'lib/aws-sdk-connectcases/types.rb', line 910 class CreateFieldRequest < Struct.new( :domain_id, :name, :type, :description, :attributes) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the field.
910 911 912 913 914 915 916 917 918 |
# File 'lib/aws-sdk-connectcases/types.rb', line 910 class CreateFieldRequest < Struct.new( :domain_id, :name, :type, :description, :attributes) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Cases domain.
910 911 912 913 914 915 916 917 918 |
# File 'lib/aws-sdk-connectcases/types.rb', line 910 class CreateFieldRequest < Struct.new( :domain_id, :name, :type, :description, :attributes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the field.
910 911 912 913 914 915 916 917 918 |
# File 'lib/aws-sdk-connectcases/types.rb', line 910 class CreateFieldRequest < Struct.new( :domain_id, :name, :type, :description, :attributes) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Defines the data type, some system constraints, and default display of the field.
910 911 912 913 914 915 916 917 918 |
# File 'lib/aws-sdk-connectcases/types.rb', line 910 class CreateFieldRequest < Struct.new( :domain_id, :name, :type, :description, :attributes) SENSITIVE = [] include Aws::Structure end |