Class: Aws::ConnectCases::Types::CreateLayoutRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::CreateLayoutRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ Types::LayoutContent
Information about which fields will be present in the layout, and information about the order of the fields.
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#name ⇒ String
The name of the layout.
Instance Attribute Details
#content ⇒ Types::LayoutContent
Information about which fields will be present in the layout, and information about the order of the fields.
952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-connectcases/types.rb', line 952 class CreateLayoutRequest < Struct.new( :domain_id, :name, :content) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Cases domain.
952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-connectcases/types.rb', line 952 class CreateLayoutRequest < Struct.new( :domain_id, :name, :content) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the layout. It must be unique for the Cases domain.
952 953 954 955 956 957 958 |
# File 'lib/aws-sdk-connectcases/types.rb', line 952 class CreateLayoutRequest < Struct.new( :domain_id, :name, :content) SENSITIVE = [] include Aws::Structure end |