Class: Aws::ConnectCases::Types::CustomUpdateContent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Represents the updated content of a ‘Custom` related item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fieldsArray<Types::FieldValue>

List of updated field values for the ‘Custom` related item. All existing and new fields, and their associated values should be included. Fields not included as part of this request will be removed.

Returns:



1214
1215
1216
1217
1218
# File 'lib/aws-sdk-connectcases/types.rb', line 1214

class CustomUpdateContent < Struct.new(
  :fields)
  SENSITIVE = []
  include Aws::Structure
end