Class: Aws::ConnectCases::Types::FieldAttributes

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Note:

FieldAttributes is a union - when making an API calls you must set exactly one of the members.

Note:

FieldAttributes is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FieldAttributes corresponding to the set member.

Union of field attributes.

Direct Known Subclasses

Text, Unknown

Defined Under Namespace

Classes: Text, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#textTypes::TextAttributes

Field attributes for Text field type.



1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
# File 'lib/aws-sdk-connectcases/types.rb', line 1433

class FieldAttributes < Struct.new(
  :text,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Text < FieldAttributes; end
  class Unknown < FieldAttributes; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



1433
1434
1435
# File 'lib/aws-sdk-connectcases/types.rb', line 1433

def unknown
  @unknown
end