Class: Aws::ConnectCases::Types::FieldOptionsCaseRule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Rules that control which options are available in a child field based on the selected value in a parent field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#child_field_idString

The identifier of the child field whose options are controlled.

Returns:

  • (String)


1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-connectcases/types.rb', line 1634

class FieldOptionsCaseRule < Struct.new(
  :parent_field_id,
  :child_field_id,
  :parent_child_field_options_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#parent_child_field_options_mappingsArray<Types::ParentChildFieldOptionsMapping>

A mapping between a parent field option value and child field option values.



1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-connectcases/types.rb', line 1634

class FieldOptionsCaseRule < Struct.new(
  :parent_field_id,
  :child_field_id,
  :parent_child_field_options_mappings)
  SENSITIVE = []
  include Aws::Structure
end

#parent_field_idString

The identifier of the parent field that controls options.

Returns:

  • (String)


1634
1635
1636
1637
1638
1639
1640
# File 'lib/aws-sdk-connectcases/types.rb', line 1634

class FieldOptionsCaseRule < Struct.new(
  :parent_field_id,
  :child_field_id,
  :parent_child_field_options_mappings)
  SENSITIVE = []
  include Aws::Structure
end