Class: Aws::ConnectCases::Types::GetCaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::GetCaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#case_id ⇒ String
A unique identifier of the case.
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#fields ⇒ Array<Types::FieldIdentifier>
A list of unique field identifiers.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#case_id ⇒ String
A unique identifier of the case.
1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1877 class GetCaseRequest < Struct.new( :case_id, :domain_id, :fields, :next_token) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Cases domain.
1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1877 class GetCaseRequest < Struct.new( :case_id, :domain_id, :fields, :next_token) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<Types::FieldIdentifier>
A list of unique field identifiers.
1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1877 class GetCaseRequest < Struct.new( :case_id, :domain_id, :fields, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
1877 1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1877 class GetCaseRequest < Struct.new( :case_id, :domain_id, :fields, :next_token) SENSITIVE = [] include Aws::Structure end |