Class: Aws::ConnectCases::Types::ListCaseRulesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_id ⇒ String

Unique identifier of a Cases domain.



2434
2435
2436
2437
2438
2439
2440
# File 'lib/aws-sdk-connectcases/types.rb', line 2434

class ListCaseRulesRequest < Struct.new(
  :domain_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return per page.



2434
2435
2436
2437
2438
2439
2440
# File 'lib/aws-sdk-connectcases/types.rb', line 2434

class ListCaseRulesRequest < Struct.new(
  :domain_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.



2434
2435
2436
2437
2438
2439
2440
# File 'lib/aws-sdk-connectcases/types.rb', line 2434

class ListCaseRulesRequest < Struct.new(
  :domain_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end