Class: Aws::ConnectCases::Types::ListDomainsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ListDomainsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return per page.
2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2519 class ListDomainsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
2519 2520 2521 2522 2523 2524 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2519 class ListDomainsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |