Class: Aws::ConnectCases::Types::ListFieldOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-connectcases/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_id ⇒ String

The unique identifier of the Cases domain.

Returns:

  • (String)


2568
2569
2570
2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-connectcases/types.rb', line 2568

class ListFieldOptionsRequest < Struct.new(
  :domain_id,
  :field_id,
  :max_results,
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#field_id ⇒ String

The unique identifier of a field.

Returns:

  • (String)


2568
2569
2570
2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-connectcases/types.rb', line 2568

class ListFieldOptionsRequest < Struct.new(
  :domain_id,
  :field_id,
  :max_results,
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to return per page.

Returns:

  • (Integer)


2568
2569
2570
2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-connectcases/types.rb', line 2568

class ListFieldOptionsRequest < Struct.new(
  :domain_id,
  :field_id,
  :max_results,
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.

Returns:

  • (String)


2568
2569
2570
2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-connectcases/types.rb', line 2568

class ListFieldOptionsRequest < Struct.new(
  :domain_id,
  :field_id,
  :max_results,
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#values ⇒ Array<String>

A list of FieldOption values to filter on for ListFieldOptions.

Returns:

  • (Array<String>)


2568
2569
2570
2571
2572
2573
2574
2575
2576
# File 'lib/aws-sdk-connectcases/types.rb', line 2568

class ListFieldOptionsRequest < Struct.new(
  :domain_id,
  :field_id,
  :max_results,
  :next_token,
  :values)
  SENSITIVE = []
  include Aws::Structure
end