Class: Aws::ConnectCases::Types::ListFieldsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ListFieldsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#domain_id ⇒ String
The unique identifier of the Cases domain.
2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2612 class ListFieldsRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2612 class ListFieldsRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
2612 2613 2614 2615 2616 2617 2618 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2612 class ListFieldsRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |