Class: Aws::ConnectCases::Types::ListLayoutsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ListLayoutsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#domain_id ⇒ String
The unique identifier of the Cases domain.
2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2654 class ListLayoutsRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2654 class ListLayoutsRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
2654 2655 2656 2657 2658 2659 2660 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2654 class ListLayoutsRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |