Class: Aws::ConnectCases::Types::RelatedItemUpdateContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::RelatedItemUpdateContent
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Note:
RelatedItemUpdateContent is a union - when making an API calls you must set exactly one of the members.
Represents the content of a related item to be updated. This is a union type that can contain either comment content or custom content.
Defined Under Namespace
Classes: Comment, Custom, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#comment ⇒ Types::CommentUpdateContent
Represents the updated content of a ‘Comment` related item.
-
#custom ⇒ Types::CustomUpdateContent
Represents the updated content of a ‘Custom` related item.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#comment ⇒ Types::CommentUpdateContent
Represents the updated content of a ‘Comment` related item.
3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3058 class RelatedItemUpdateContent < Struct.new( :comment, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Comment < RelatedItemUpdateContent; end class Custom < RelatedItemUpdateContent; end class Unknown < RelatedItemUpdateContent; end end |
#custom ⇒ Types::CustomUpdateContent
Represents the updated content of a ‘Custom` related item.
3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 3069 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3058 class RelatedItemUpdateContent < Struct.new( :comment, :custom, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Comment < RelatedItemUpdateContent; end class Custom < RelatedItemUpdateContent; end class Unknown < RelatedItemUpdateContent; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
3058 3059 3060 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3058 def unknown @unknown end |