Class: Aws::ConnectCases::Types::ResourceNotFoundException
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ResourceNotFoundException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
We couldn’t find the requested resource. Check that your resources exists and were created in the same Amazon Web Services Region as your request, and try your request again.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#resource_id ⇒ String
Unique identifier of the resource affected.
-
#resource_type ⇒ String
Type of the resource affected.
Instance Attribute Details
#message ⇒ String
3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3057 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_id ⇒ String
Unique identifier of the resource affected.
3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3057 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Type of the resource affected.
3057 3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3057 class ResourceNotFoundException < Struct.new( :message, :resource_id, :resource_type) SENSITIVE = [] include Aws::Structure end |