Class: Aws::ConnectCases::Types::SearchCasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::SearchCasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#fields ⇒ Array<Types::FieldIdentifier>
The list of field identifiers to be returned as part of the response.
-
#filter ⇒ Types::CaseFilter
A list of filter objects.
-
#max_results ⇒ Integer
The maximum number of cases to return.
-
#next_token ⇒ String
The token for the next set of results.
-
#search_term ⇒ String
A word or phrase used to perform a quick search.
-
#sorts ⇒ Array<Types::Sort>
A list of sorts where each sort specifies a field and their sort order to be applied to the results.
Instance Attribute Details
#domain_id ⇒ String
The unique identifier of the Cases domain.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |
#fields ⇒ Array<Types::FieldIdentifier>
The list of field identifiers to be returned as part of the response.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::CaseFilter
A list of filter objects.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of cases to return. When no value is provided, 25 is the default.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |
#search_term ⇒ String
A word or phrase used to perform a quick search.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |
#sorts ⇒ Array<Types::Sort>
A list of sorts where each sort specifies a field and their sort order to be applied to the results.
3302 3303 3304 3305 3306 3307 3308 3309 3310 3311 3312 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3302 class SearchCasesRequest < Struct.new( :domain_id, :max_results, :next_token, :search_term, :filter, :sorts, :fields) SENSITIVE = [] include Aws::Structure end |