Class: Aws::ConnectCases::Types::SearchRelatedItemsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::SearchRelatedItemsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#case_id ⇒ String
A unique identifier of the case.
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#filters ⇒ Array<Types::RelatedItemTypeFilter>
The list of types of related items and their parameters to use for filtering.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#case_id ⇒ String
A unique identifier of the case.
3393 3394 3395 3396 3397 3398 3399 3400 3401 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3393 class SearchRelatedItemsRequest < Struct.new( :domain_id, :case_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Cases domain.
3393 3394 3395 3396 3397 3398 3399 3400 3401 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3393 class SearchRelatedItemsRequest < Struct.new( :domain_id, :case_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::RelatedItemTypeFilter>
The list of types of related items and their parameters to use for filtering.
3393 3394 3395 3396 3397 3398 3399 3400 3401 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3393 class SearchRelatedItemsRequest < Struct.new( :domain_id, :case_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
3393 3394 3395 3396 3397 3398 3399 3400 3401 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3393 class SearchRelatedItemsRequest < Struct.new( :domain_id, :case_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
3393 3394 3395 3396 3397 3398 3399 3400 3401 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3393 class SearchRelatedItemsRequest < Struct.new( :domain_id, :case_id, :max_results, :next_token, :filters) SENSITIVE = [] include Aws::Structure end |