Class: Aws::ConnectCases::Types::UpdateLayoutRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::UpdateLayoutRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content ⇒ Types::LayoutContent
Information about which fields will be present in the layout, the order of the fields.
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#layout_id ⇒ String
The unique identifier of the layout.
-
#name ⇒ String
The name of the layout.
Instance Attribute Details
#content ⇒ Types::LayoutContent
Information about which fields will be present in the layout, the order of the fields.
3895 3896 3897 3898 3899 3900 3901 3902 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3895 class UpdateLayoutRequest < Struct.new( :domain_id, :layout_id, :name, :content) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Cases domain.
3895 3896 3897 3898 3899 3900 3901 3902 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3895 class UpdateLayoutRequest < Struct.new( :domain_id, :layout_id, :name, :content) SENSITIVE = [] include Aws::Structure end |
#layout_id ⇒ String
The unique identifier of the layout.
3895 3896 3897 3898 3899 3900 3901 3902 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3895 class UpdateLayoutRequest < Struct.new( :domain_id, :layout_id, :name, :content) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the layout. It must be unique per domain.
3895 3896 3897 3898 3899 3900 3901 3902 |
# File 'lib/aws-sdk-connectcases/types.rb', line 3895 class UpdateLayoutRequest < Struct.new( :domain_id, :layout_id, :name, :content) SENSITIVE = [] include Aws::Structure end |