Class: Aws::ConnectCases::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCases::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcases/client.rb
Overview
An API client for ConnectCases. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCases::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_case_rule(params = {}) ⇒ Types::BatchGetCaseRuleResponse
Gets a batch of case rules.
-
#batch_get_field(params = {}) ⇒ Types::BatchGetFieldResponse
Returns the description for the list of fields in the request parameters.
-
#batch_put_field_options(params = {}) ⇒ Types::BatchPutFieldOptionsResponse
Creates and updates a set of field options for a single select field in a Cases domain.
-
#create_case(params = {}) ⇒ Types::CreateCaseResponse
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have [connect:DescribeUser] permission on the User ARN resource that you provide.
-
#create_case_rule(params = {}) ⇒ Types::CreateCaseRuleResponse
Creates a new case rule.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts.
-
#create_field(params = {}) ⇒ Types::CreateFieldResponse
Creates a field in the Cases domain.
-
#create_layout(params = {}) ⇒ Types::CreateLayoutResponse
Creates a layout in the Cases domain.
-
#create_related_item(params = {}) ⇒ Types::CreateRelatedItemResponse
Creates a related item (comments, tasks, and contacts) and associates it with a case.
-
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a template in the Cases domain.
-
#delete_case(params = {}) ⇒ Struct
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store.
-
#delete_case_rule(params = {}) ⇒ Struct
Deletes a case rule.
-
#delete_domain(params = {}) ⇒ Struct
Deletes a Cases domain.
-
#delete_field(params = {}) ⇒ Struct
Deletes a field from a cases template.
-
#delete_layout(params = {}) ⇒ Struct
Deletes a layout from a cases template.
-
#delete_related_item(params = {}) ⇒ Struct
Deletes the related item resource under a case.
-
#delete_template(params = {}) ⇒ Struct
Deletes a cases template.
-
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns information about a specific case if it exists.
-
#get_case_audit_events(params = {}) ⇒ Types::GetCaseAuditEventsResponse
Returns the audit history about a specific case if it exists.
-
#get_case_event_configuration(params = {}) ⇒ Types::GetCaseEventConfigurationResponse
Returns the case event publishing configuration.
-
#get_domain(params = {}) ⇒ Types::GetDomainResponse
Returns information about a specific domain if it exists.
-
#get_layout(params = {}) ⇒ Types::GetLayoutResponse
Returns the details for the requested layout.
-
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Returns the details for the requested template.
-
#list_case_rules(params = {}) ⇒ Types::ListCaseRulesResponse
Lists all case rules in a Cases domain.
-
#list_cases_for_contact(params = {}) ⇒ Types::ListCasesForContactResponse
Lists cases for a given contact.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all cases domains in the Amazon Web Services account.
-
#list_field_options(params = {}) ⇒ Types::ListFieldOptionsResponse
Lists all of the field options for a field identifier in the domain.
-
#list_fields(params = {}) ⇒ Types::ListFieldsResponse
Lists all fields in a Cases domain.
-
#list_layouts(params = {}) ⇒ Types::ListLayoutsResponse
Lists all layouts in the given cases domain.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
-
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists all of the templates in a Cases domain.
-
#put_case_event_configuration(params = {}) ⇒ Struct
Adds case event publishing configuration.
-
#search_all_related_items(params = {}) ⇒ Types::SearchAllRelatedItemsResponse
Searches for related items across all cases within a domain.
-
#search_cases(params = {}) ⇒ Types::SearchCasesResponse
Searches for cases within their associated Cases domain.
-
#search_related_items(params = {}) ⇒ Types::SearchRelatedItemsResponse
Searches for related items that are associated with a case.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
-
#update_case(params = {}) ⇒ Struct
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have [connect:DescribeUser] permission on the User ARN resource that you provide.
-
#update_case_rule(params = {}) ⇒ Struct
Updates a case rule.
-
#update_field(params = {}) ⇒ Struct
Updates the properties of an existing field.
-
#update_layout(params = {}) ⇒ Struct
Updates the attributes of an existing layout.
-
#update_related_item(params = {}) ⇒ Types::UpdateRelatedItemResponse
Updates the content of a related item associated with a case.
-
#update_template(params = {}) ⇒ Struct
Updates the attributes of an existing template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-connectcases/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3648 3649 3650 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3648 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3651 3652 3653 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3651 def errors_module Errors end |
Instance Method Details
#batch_get_case_rule(params = {}) ⇒ Types::BatchGetCaseRuleResponse
Gets a batch of case rules. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
566 567 568 569 |
# File 'lib/aws-sdk-connectcases/client.rb', line 566 def batch_get_case_rule(params = {}, = {}) req = build_request(:batch_get_case_rule, params) req.send_request() end |
#batch_get_field(params = {}) ⇒ Types::BatchGetFieldResponse
Returns the description for the list of fields in the request parameters.
620 621 622 623 |
# File 'lib/aws-sdk-connectcases/client.rb', line 620 def batch_get_field(params = {}, = {}) req = build_request(:batch_get_field, params) req.send_request() end |
#batch_put_field_options(params = {}) ⇒ Types::BatchPutFieldOptionsResponse
Creates and updates a set of field options for a single select field in a Cases domain.
666 667 668 669 |
# File 'lib/aws-sdk-connectcases/client.rb', line 666 def (params = {}, = {}) req = build_request(:batch_put_field_options, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3621 3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3621 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCases') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcases' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#create_case(params = {}) ⇒ Types::CreateCaseResponse
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have
- connect:DescribeUser][1
-
permission on the User ARN resource that you
provide
</note>
Creates a case in the specified Cases domain. Case system and custom
fields are taken as an array id/value pairs with a declared data types.
When creating a case from a template that has tag propagation
configurations, the specified tags are automatically applied to the case.
The following fields are required when creating a case:
* `customer_id` - You must provide the full customer profile ARN in
this format: `arn:aws:profile:your_AWS_Region:your_AWS_account
ID:domains/your_profiles_domain_name/profiles/profile_ID`
-
‘title`
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html
770 771 772 773 |
# File 'lib/aws-sdk-connectcases/client.rb', line 770 def create_case(params = {}, = {}) req = build_request(:create_case, params) req.send_request() end |
#create_case_rule(params = {}) ⇒ Types::CreateCaseRuleResponse
Creates a new case rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
916 917 918 919 |
# File 'lib/aws-sdk-connectcases/client.rb', line 916 def create_case_rule(params = {}, = {}) req = build_request(:create_case_rule, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts. Each Amazon Connect instance can be associated with only one Cases domain.
This will not associate your connect instance to Cases domain. Instead, use the Amazon Connect [CreateIntegrationAssociation] API. You need specific IAM permissions to successfully associate the Cases domain. For more information, see [Onboard to Cases].
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_CreateIntegrationAssociation.html [2]: docs.aws.amazon.com/connect/latest/adminguide/required-permissions-iam-cases.html#onboard-cases-iam
961 962 963 964 |
# File 'lib/aws-sdk-connectcases/client.rb', line 961 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_field(params = {}) ⇒ Types::CreateFieldResponse
Creates a field in the Cases domain. This field is used to define the case object model (that is, defines what data can be captured on cases) in a Cases domain.
1014 1015 1016 1017 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1014 def create_field(params = {}, = {}) req = build_request(:create_field, params) req.send_request() end |
#create_layout(params = {}) ⇒ Types::CreateLayoutResponse
Creates a layout in the Cases domain. Layouts define the following configuration in the top section and More Info tab of the Cases user interface:
-
Fields to display to the users
-
Field ordering
<note markdown=“1”> Title and Status fields cannot be part of layouts since they are not configurable.
</note>
1095 1096 1097 1098 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1095 def create_layout(params = {}, = {}) req = build_request(:create_layout, params) req.send_request() end |
#create_related_item(params = {}) ⇒ Types::CreateRelatedItemResponse
Creates a related item (comments, tasks, and contacts) and associates it with a case.
There’s a quota for the number of fields allowed in a Custom type related item. See [Amazon Connect Cases quotas].
**Use cases**
Following are examples of related items that you may want to associate with a case:
-
Related contacts, such as calls, chats, emails tasks
-
Comments, for agent notes
-
SLAs, to capture target resolution goals
-
Cases, to capture related Amazon Connect Cases
-
Files, such as policy documentation or customer-provided attachments
-
Custom related items, which provide flexibility for you to define related items that such as bookings, orders, products, notices, and more
**Important things to know**
-
If you are associating a contact to a case by passing in ‘Contact` for a `type`, you must have [DescribeContact] permission on the ARN of the contact that you provide in `content.contact.contactArn`.
-
A Related Item is a resource that is associated with a case. It may or may not have an external identifier linking it to an external resource (for example, a ‘contactArn`). All Related Items have their own internal identifier, the `relatedItemArn`. Examples of related items include `comments` and `contacts`.
-
If you provide a value for ‘performedBy.userArn` you must also have
- DescribeUser][3
-
permission on the ARN of the user that you
provide.
-
The ‘type` field is reserved for internal use only.
Endpoints: See [Amazon Connect endpoints and quotas].
[1]: docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#cases-quotas [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeContact.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html [4]: docs.aws.amazon.com/general/latest/gr/connect_region.html
1241 1242 1243 1244 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1241 def (params = {}, = {}) req = build_request(:create_related_item, params) req.send_request() end |
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a template in the Cases domain. This template is used to define the case object model (that is, to define what data can be captured on cases) in a Cases domain. A template must have a unique name within a domain, and it must reference existing field IDs and layout IDs. Additionally, multiple fields with same IDs are not allowed within the same Template. A template can be either Active or Inactive, as indicated by its status. Inactive templates cannot be used to create cases.
Other template APIs are:
- DeleteTemplate][1
- GetTemplate][2
- ListTemplates][3
- UpdateTemplate][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_ListTemplates.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_UpdateTemplate.html
1349 1350 1351 1352 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1349 def create_template(params = {}, = {}) req = build_request(:create_template, params) req.send_request() end |
#delete_case(params = {}) ⇒ Struct
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store. After a successful deletion, you cannot:
-
Retrieve related items
-
Access audit history
-
Perform any operations that require the CaseID
This action is irreversible. After you delete a case, you cannot recover its data.
1386 1387 1388 1389 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1386 def delete_case(params = {}, = {}) req = build_request(:delete_case, params) req.send_request() end |
#delete_case_rule(params = {}) ⇒ Struct
Deletes a case rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
1419 1420 1421 1422 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1419 def delete_case_rule(params = {}, = {}) req = build_request(:delete_case_rule, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Struct
Deletes a Cases domain.
<note markdown=“1”> After deleting your domain you must disassociate the deleted domain from your Amazon Connect instance with another API call before being able to use Cases again with this Amazon Connect instance. See [DeleteIntegrationAssociation].
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteIntegrationAssociation.html
1452 1453 1454 1455 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1452 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_field(params = {}) ⇒ Struct
Deletes a field from a cases template.
After a field is deleted:
-
You can still retrieve the field by calling ‘BatchGetField`.
-
You cannot update a deleted field by calling ‘UpdateField`; it throws a `ValidationException`.
-
Deleted fields are not included in the ‘ListFields` response.
-
Calling ‘CreateCase` with a deleted field throws a `ValidationException` denoting which field identifiers in the request have been deleted.
-
Calling ‘GetCase` with a deleted field identifier returns the deleted field’s value if one exists.
-
Calling ‘UpdateCase` with a deleted field ID throws a `ValidationException` if the case does not already contain a value for the deleted field. Otherwise it succeeds, allowing you to update or remove (using `emptyValue: {}`) the field’s value from the case.
-
‘GetTemplate` does not return field IDs for deleted fields.
-
‘GetLayout` does not return field IDs for deleted fields.
-
Calling ‘SearchCases` with the deleted field ID as a filter returns any cases that have a value for the deleted field that matches the filter criteria.
-
Calling ‘SearchCases` with a `searchTerm` value that matches a deleted field’s value on a case returns the case in the response.
-
Calling ‘BatchPutFieldOptions` with a deleted field ID throw a `ValidationException`.
-
Calling ‘GetCaseEventConfiguration` does not return field IDs for deleted fields.
1516 1517 1518 1519 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1516 def delete_field(params = {}, = {}) req = build_request(:delete_field, params) req.send_request() end |
#delete_layout(params = {}) ⇒ Struct
Deletes a layout from a cases template. You can delete up to 100 layouts per domain.
After a layout is deleted:
-
You can still retrieve the layout by calling ‘GetLayout`.
-
You cannot update a deleted layout by calling ‘UpdateLayout`; it throws a `ValidationException`.
-
Deleted layouts are not included in the ‘ListLayouts` response.
1552 1553 1554 1555 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1552 def delete_layout(params = {}, = {}) req = build_request(:delete_layout, params) req.send_request() end |
#delete_related_item(params = {}) ⇒ Struct
Deletes the related item resource under a case.
<note markdown=“1”> This API cannot be used on a FILE type related attachment. To delete this type of file, use the [DeleteAttachedFile] API
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteAttachedFile.html
1591 1592 1593 1594 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1591 def (params = {}, = {}) req = build_request(:delete_related_item, params) req.send_request() end |
#delete_template(params = {}) ⇒ Struct
Deletes a cases template. You can delete up to 100 templates per domain.
After a cases template is deleted:
-
You can still retrieve the template by calling ‘GetTemplate`.
-
You cannot update the template.
-
You cannot create a case by using the deleted template.
-
Deleted templates are not included in the ‘ListTemplates` response.
1628 1629 1630 1631 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1628 def delete_template(params = {}, = {}) req = build_request(:delete_template, params) req.send_request() end |
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns information about a specific case if it exists.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1688 1689 1690 1691 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1688 def get_case(params = {}, = {}) req = build_request(:get_case, params) req.send_request() end |
#get_case_audit_events(params = {}) ⇒ Types::GetCaseAuditEventsResponse
Returns the audit history about a specific case if it exists.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1752 1753 1754 1755 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1752 def get_case_audit_events(params = {}, = {}) req = build_request(:get_case_audit_events, params) req.send_request() end |
#get_case_event_configuration(params = {}) ⇒ Types::GetCaseEventConfigurationResponse
Returns the case event publishing configuration.
1783 1784 1785 1786 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1783 def get_case_event_configuration(params = {}, = {}) req = build_request(:get_case_event_configuration, params) req.send_request() end |
#get_domain(params = {}) ⇒ Types::GetDomainResponse
Returns information about a specific domain if it exists.
1822 1823 1824 1825 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1822 def get_domain(params = {}, = {}) req = build_request(:get_domain, params) req.send_request() end |
#get_layout(params = {}) ⇒ Types::GetLayoutResponse
Returns the details for the requested layout.
1876 1877 1878 1879 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1876 def get_layout(params = {}, = {}) req = build_request(:get_layout, params) req.send_request() end |
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Returns the details for the requested template. Other template APIs are:
- CreateTemplate][1
- DeleteTemplate][2
- ListTemplates][3
- UpdateTemplate][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_CreateTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_ListTemplates.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_UpdateTemplate.html
1955 1956 1957 1958 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1955 def get_template(params = {}, = {}) req = build_request(:get_template, params) req.send_request() end |
#list_case_rules(params = {}) ⇒ Types::ListCaseRulesResponse
Lists all case rules in a Cases domain. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2009 2010 2011 2012 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2009 def list_case_rules(params = {}, = {}) req = build_request(:list_case_rules, params) req.send_request() end |
#list_cases_for_contact(params = {}) ⇒ Types::ListCasesForContactResponse
Lists cases for a given contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2057 2058 2059 2060 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2057 def list_cases_for_contact(params = {}, = {}) req = build_request(:list_cases_for_contact, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all cases domains in the Amazon Web Services account. Each list item is a condensed summary object of the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2099 2100 2101 2102 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2099 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_field_options(params = {}) ⇒ Types::ListFieldOptionsResponse
Lists all of the field options for a field identifier in the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2152 2153 2154 2155 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2152 def (params = {}, = {}) req = build_request(:list_field_options, params) req.send_request() end |
#list_fields(params = {}) ⇒ Types::ListFieldsResponse
Lists all fields in a Cases domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2200 2201 2202 2203 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2200 def list_fields(params = {}, = {}) req = build_request(:list_fields, params) req.send_request() end |
#list_layouts(params = {}) ⇒ Types::ListLayoutsResponse
Lists all layouts in the given cases domain. Each list item is a condensed summary object of the layout.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2246 2247 2248 2249 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2246 def list_layouts(params = {}, = {}) req = build_request(:list_layouts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
2275 2276 2277 2278 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2275 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists all of the templates in a Cases domain. Each list item is a condensed summary object of the template.
Other template APIs are:
- CreateTemplate][1
- DeleteTemplate][2
- GetTemplate][3
- UpdateTemplate][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_CreateTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetTemplate.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_UpdateTemplate.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2347 2348 2349 2350 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2347 def list_templates(params = {}, = {}) req = build_request(:list_templates, params) req.send_request() end |
#put_case_event_configuration(params = {}) ⇒ Struct
Adds case event publishing configuration. For a complete list of fields you can add to the event message, see [Create case fields] in the *Amazon Connect Administrator Guide*
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-fields.html
2394 2395 2396 2397 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2394 def put_case_event_configuration(params = {}, = {}) req = build_request(:put_case_event_configuration, params) req.send_request() end |
#search_all_related_items(params = {}) ⇒ Types::SearchAllRelatedItemsResponse
Searches for related items across all cases within a domain. This is a global search operation that returns related items from multiple cases, unlike the case-specific [SearchRelatedItems] API.
**Use cases**
Following are common uses cases for this API:
-
Find cases with similar issues across the domain. For example, search for all cases containing comments about “product defect” to identify patterns and existing solutions.
-
Locate all cases associated with specific contacts or orders. For example, find all cases linked to a contactArn to understand the complete customer journey.
-
Monitor SLA compliance across cases. For example, search for all cases with “Active” SLA status to prioritize remediation efforts.
**Important things to know**
-
This API returns case identifiers, not complete case objects. To retrieve full case details, you must make additional calls to the
- GetCase][2
-
API for each returned case ID.
-
This API searches across related items content, not case fields. Use the [SearchCases] API to search within case field values.
Endpoints: See [Amazon Connect endpoints and quotas].
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_SearchRelatedItems.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetCase.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_SearchCases.html [4]: docs.aws.amazon.com/general/latest/gr/connect_region.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2625 2626 2627 2628 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2625 def (params = {}, = {}) req = build_request(:search_all_related_items, params) req.send_request() end |
#search_cases(params = {}) ⇒ Types::SearchCasesResponse
Searches for cases within their associated Cases domain. Search results are returned as a paginated list of abridged case documents.
<note markdown=“1”> For ‘customer_id` you must provide the full customer profile ARN in this format: ` arn:aws:profile:your AWS Region:your AWS account ID:domains/profiles domain name/profiles/profile ID`.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2801 2802 2803 2804 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2801 def search_cases(params = {}, = {}) req = build_request(:search_cases, params) req.send_request() end |
#search_related_items(params = {}) ⇒ Types::SearchRelatedItemsResponse
Searches for related items that are associated with a case.
<note markdown=“1”> If no filters are provided, this returns all related items associated with a case.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2992 2993 2994 2995 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2992 def (params = {}, = {}) req = build_request(:search_related_items, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
3021 3022 3023 3024 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3021 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
3047 3048 3049 3050 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3047 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_case(params = {}) ⇒ Struct
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have
- connect:DescribeUser][1
-
permission on the User ARN resource that you
provide
</note>
Updates the values of fields on a case. Fields to be updated are
received as an array of id/value pairs identical to the ‘CreateCase` input .
If the action is successful, the service sends back an HTTP 200
response with an empty HTTP body.
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html
3113 3114 3115 3116 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3113 def update_case(params = {}, = {}) req = build_request(:update_case, params) req.send_request() end |
#update_case_rule(params = {}) ⇒ Struct
Updates a case rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
3255 3256 3257 3258 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3255 def update_case_rule(params = {}, = {}) req = build_request(:update_case_rule, params) req.send_request() end |
#update_field(params = {}) ⇒ Struct
Updates the properties of an existing field.
3297 3298 3299 3300 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3297 def update_field(params = {}, = {}) req = build_request(:update_field, params) req.send_request() end |
#update_layout(params = {}) ⇒ Struct
Updates the attributes of an existing layout.
If the action is successful, the service sends back an HTTP 200 response with an empty HTTP body.
A ‘ValidationException` is returned when you add non-existent `fieldIds` to a layout.
<note markdown=“1”> Title and Status fields cannot be part of layouts because they are not configurable.
</note>
3374 3375 3376 3377 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3374 def update_layout(params = {}, = {}) req = build_request(:update_layout, params) req.send_request() end |
#update_related_item(params = {}) ⇒ Types::UpdateRelatedItemResponse
Updates the content of a related item associated with a case. The following related item types are supported:
-
Comment - Update the text content of an existing comment
-
Custom - Update the fields of a custom related item. You can add, modify, and remove fields from a custom related item. There’s a quota for the number of fields allowed in a Custom type related item. See [Amazon Connect Cases quotas].
**Important things to know**
-
When updating a Custom related item, all existing and new fields, and their associated values should be included in the request. Fields not included as part of this request will be removed.
-
If you provide a value for ‘performedBy.userArn` you must also have
- DescribeUser][2
-
permission on the ARN of the user that you
provide.
- System case fields][3
-
cannot be used in a custom related item.
Endpoints: See [Amazon Connect endpoints and quotas].
[1]: docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#cases-quotas [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html [3]: docs.aws.amazon.com/connect/latest/adminguide/case-fields.html#system-case-fields [4]: docs.aws.amazon.com/general/latest/gr/connect_region.html
3510 3511 3512 3513 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3510 def (params = {}, = {}) req = build_request(:update_related_item, params) req.send_request() end |
#update_template(params = {}) ⇒ Struct
Updates the attributes of an existing template. The template attributes that can be modified include ‘name`, `description`, `layoutConfiguration`, `requiredFields`, and `status`. At least one of these attributes must not be null. If a null value is provided for a given attribute, that attribute is ignored and its current value is preserved.
Other template APIs are:
- CreateTemplate][1
- DeleteTemplate][2
- GetTemplate][3
- ListTemplates][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_CreateTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetTemplate.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_ListTemplates.html
3612 3613 3614 3615 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3612 def update_template(params = {}, = {}) req = build_request(:update_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3641 3642 3643 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3641 def waiter_names [] end |