Class: Aws::ConnectCases::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ConnectCases::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-connectcases/client.rb
Overview
An API client for ConnectCases. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ConnectCases::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_case_rule(params = {}) ⇒ Types::BatchGetCaseRuleResponse
Gets a batch of case rules.
-
#batch_get_field(params = {}) ⇒ Types::BatchGetFieldResponse
Returns the description for the list of fields in the request parameters.
-
#batch_put_field_options(params = {}) ⇒ Types::BatchPutFieldOptionsResponse
Creates and updates a set of field options for a single select field in a Cases domain.
-
#create_case(params = {}) ⇒ Types::CreateCaseResponse
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have [connect:DescribeUser] permission on the User ARN resource that you provide.
-
#create_case_rule(params = {}) ⇒ Types::CreateCaseRuleResponse
Creates a new case rule.
-
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts.
-
#create_field(params = {}) ⇒ Types::CreateFieldResponse
Creates a field in the Cases domain.
-
#create_layout(params = {}) ⇒ Types::CreateLayoutResponse
Creates a layout in the Cases domain.
-
#create_related_item(params = {}) ⇒ Types::CreateRelatedItemResponse
Creates a related item (comments, tasks, and contacts) and associates it with a case.
-
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a template in the Cases domain.
-
#delete_case(params = {}) ⇒ Struct
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store.
-
#delete_case_rule(params = {}) ⇒ Struct
Deletes a case rule.
-
#delete_domain(params = {}) ⇒ Struct
Deletes a Cases domain.
-
#delete_field(params = {}) ⇒ Struct
Deletes a field from a cases template.
-
#delete_layout(params = {}) ⇒ Struct
Deletes a layout from a cases template.
-
#delete_related_item(params = {}) ⇒ Struct
Deletes the related item resource under a case.
-
#delete_template(params = {}) ⇒ Struct
Deletes a cases template.
-
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns information about a specific case if it exists.
-
#get_case_audit_events(params = {}) ⇒ Types::GetCaseAuditEventsResponse
Returns the audit history about a specific case if it exists.
-
#get_case_event_configuration(params = {}) ⇒ Types::GetCaseEventConfigurationResponse
Returns the case event publishing configuration.
-
#get_domain(params = {}) ⇒ Types::GetDomainResponse
Returns information about a specific domain if it exists.
-
#get_layout(params = {}) ⇒ Types::GetLayoutResponse
Returns the details for the requested layout.
-
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Returns the details for the requested template.
-
#list_case_rules(params = {}) ⇒ Types::ListCaseRulesResponse
Lists all case rules in a Cases domain.
-
#list_cases_for_contact(params = {}) ⇒ Types::ListCasesForContactResponse
Lists cases for a given contact.
-
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all cases domains in the Amazon Web Services account.
-
#list_field_options(params = {}) ⇒ Types::ListFieldOptionsResponse
Lists all of the field options for a field identifier in the domain.
-
#list_fields(params = {}) ⇒ Types::ListFieldsResponse
Lists all fields in a Cases domain.
-
#list_layouts(params = {}) ⇒ Types::ListLayoutsResponse
Lists all layouts in the given cases domain.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
-
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists all of the templates in a Cases domain.
-
#put_case_event_configuration(params = {}) ⇒ Struct
Adds case event publishing configuration.
-
#search_all_related_items(params = {}) ⇒ Types::SearchAllRelatedItemsResponse
Searches for related items across all cases within a domain.
-
#search_cases(params = {}) ⇒ Types::SearchCasesResponse
Searches for cases within their associated Cases domain.
-
#search_related_items(params = {}) ⇒ Types::SearchRelatedItemsResponse
Searches for related items that are associated with a case.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
-
#update_case(params = {}) ⇒ Struct
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have [connect:DescribeUser] permission on the User ARN resource that you provide.
-
#update_case_rule(params = {}) ⇒ Struct
Updates a case rule.
-
#update_field(params = {}) ⇒ Struct
Updates the properties of an existing field.
-
#update_layout(params = {}) ⇒ Struct
Updates the attributes of an existing layout.
-
#update_related_item(params = {}) ⇒ Types::UpdateRelatedItemResponse
Updates the content of a related item associated with a case.
-
#update_template(params = {}) ⇒ Struct
Updates the attributes of an existing template.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-connectcases/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3650 3651 3652 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3650 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3653 3654 3655 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3653 def errors_module Errors end |
Instance Method Details
#batch_get_case_rule(params = {}) ⇒ Types::BatchGetCaseRuleResponse
Gets a batch of case rules. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
568 569 570 571 |
# File 'lib/aws-sdk-connectcases/client.rb', line 568 def batch_get_case_rule(params = {}, = {}) req = build_request(:batch_get_case_rule, params) req.send_request() end |
#batch_get_field(params = {}) ⇒ Types::BatchGetFieldResponse
Returns the description for the list of fields in the request parameters.
622 623 624 625 |
# File 'lib/aws-sdk-connectcases/client.rb', line 622 def batch_get_field(params = {}, = {}) req = build_request(:batch_get_field, params) req.send_request() end |
#batch_put_field_options(params = {}) ⇒ Types::BatchPutFieldOptionsResponse
Creates and updates a set of field options for a single select field in a Cases domain.
668 669 670 671 |
# File 'lib/aws-sdk-connectcases/client.rb', line 668 def (params = {}, = {}) req = build_request(:batch_put_field_options, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3623 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ConnectCases') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-connectcases' context[:gem_version] = '1.66.0' Seahorse::Client::Request.new(handlers, context) end |
#create_case(params = {}) ⇒ Types::CreateCaseResponse
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have
- connect:DescribeUser][1
-
permission on the User ARN resource that you
provide
</note>
Creates a case in the specified Cases domain. Case system and custom
fields are taken as an array id/value pairs with a declared data types.
When creating a case from a template that has tag propagation
configurations, the specified tags are automatically applied to the case.
The following fields are required when creating a case:
* `customer_id` - You must provide the full customer profile ARN in
this format: `arn:aws:profile:your_AWS_Region:your_AWS_account
ID:domains/your_profiles_domain_name/profiles/profile_ID`
-
‘title`
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html
772 773 774 775 |
# File 'lib/aws-sdk-connectcases/client.rb', line 772 def create_case(params = {}, = {}) req = build_request(:create_case, params) req.send_request() end |
#create_case_rule(params = {}) ⇒ Types::CreateCaseRuleResponse
Creates a new case rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
918 919 920 921 |
# File 'lib/aws-sdk-connectcases/client.rb', line 918 def create_case_rule(params = {}, = {}) req = build_request(:create_case_rule, params) req.send_request() end |
#create_domain(params = {}) ⇒ Types::CreateDomainResponse
Creates a domain, which is a container for all case data, such as cases, fields, templates and layouts. Each Amazon Connect instance can be associated with only one Cases domain.
This will not associate your connect instance to Cases domain. Instead, use the Amazon Connect [CreateIntegrationAssociation] API. You need specific IAM permissions to successfully associate the Cases domain. For more information, see [Onboard to Cases].
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_CreateIntegrationAssociation.html [2]: docs.aws.amazon.com/connect/latest/adminguide/required-permissions-iam-cases.html#onboard-cases-iam
963 964 965 966 |
# File 'lib/aws-sdk-connectcases/client.rb', line 963 def create_domain(params = {}, = {}) req = build_request(:create_domain, params) req.send_request() end |
#create_field(params = {}) ⇒ Types::CreateFieldResponse
Creates a field in the Cases domain. This field is used to define the case object model (that is, defines what data can be captured on cases) in a Cases domain.
1016 1017 1018 1019 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1016 def create_field(params = {}, = {}) req = build_request(:create_field, params) req.send_request() end |
#create_layout(params = {}) ⇒ Types::CreateLayoutResponse
Creates a layout in the Cases domain. Layouts define the following configuration in the top section and More Info tab of the Cases user interface:
-
Fields to display to the users
-
Field ordering
<note markdown=“1”> Title and Status fields cannot be part of layouts since they are not configurable.
</note>
1097 1098 1099 1100 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1097 def create_layout(params = {}, = {}) req = build_request(:create_layout, params) req.send_request() end |
#create_related_item(params = {}) ⇒ Types::CreateRelatedItemResponse
Creates a related item (comments, tasks, and contacts) and associates it with a case.
There’s a quota for the number of fields allowed in a Custom type related item. See [Amazon Connect Cases quotas].
**Use cases**
Following are examples of related items that you may want to associate with a case:
-
Related contacts, such as calls, chats, emails tasks
-
Comments, for agent notes
-
SLAs, to capture target resolution goals
-
Cases, to capture related Amazon Connect Cases
-
Files, such as policy documentation or customer-provided attachments
-
Custom related items, which provide flexibility for you to define related items that such as bookings, orders, products, notices, and more
**Important things to know**
-
If you are associating a contact to a case by passing in ‘Contact` for a `type`, you must have [DescribeContact] permission on the ARN of the contact that you provide in `content.contact.contactArn`.
-
A Related Item is a resource that is associated with a case. It may or may not have an external identifier linking it to an external resource (for example, a ‘contactArn`). All Related Items have their own internal identifier, the `relatedItemArn`. Examples of related items include `comments` and `contacts`.
-
If you provide a value for ‘performedBy.userArn` you must also have
- DescribeUser][3
-
permission on the ARN of the user that you
provide.
-
The ‘type` field is reserved for internal use only.
Endpoints: See [Amazon Connect endpoints and quotas].
[1]: docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#cases-quotas [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeContact.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html [4]: docs.aws.amazon.com/general/latest/gr/connect_region.html
1243 1244 1245 1246 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1243 def (params = {}, = {}) req = build_request(:create_related_item, params) req.send_request() end |
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates a template in the Cases domain. This template is used to define the case object model (that is, to define what data can be captured on cases) in a Cases domain. A template must have a unique name within a domain, and it must reference existing field IDs and layout IDs. Additionally, multiple fields with same IDs are not allowed within the same Template. A template can be either Active or Inactive, as indicated by its status. Inactive templates cannot be used to create cases.
Other template APIs are:
- DeleteTemplate][1
- GetTemplate][2
- ListTemplates][3
- UpdateTemplate][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_ListTemplates.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_UpdateTemplate.html
1351 1352 1353 1354 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1351 def create_template(params = {}, = {}) req = build_request(:create_template, params) req.send_request() end |
#delete_case(params = {}) ⇒ Struct
The DeleteCase API permanently deletes a case and all its associated resources from the cases data store. After a successful deletion, you cannot:
-
Retrieve related items
-
Access audit history
-
Perform any operations that require the CaseID
This action is irreversible. After you delete a case, you cannot recover its data.
1388 1389 1390 1391 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1388 def delete_case(params = {}, = {}) req = build_request(:delete_case, params) req.send_request() end |
#delete_case_rule(params = {}) ⇒ Struct
Deletes a case rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
1421 1422 1423 1424 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1421 def delete_case_rule(params = {}, = {}) req = build_request(:delete_case_rule, params) req.send_request() end |
#delete_domain(params = {}) ⇒ Struct
Deletes a Cases domain.
<note markdown=“1”> After deleting your domain you must disassociate the deleted domain from your Amazon Connect instance with another API call before being able to use Cases again with this Amazon Connect instance. See [DeleteIntegrationAssociation].
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteIntegrationAssociation.html
1454 1455 1456 1457 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1454 def delete_domain(params = {}, = {}) req = build_request(:delete_domain, params) req.send_request() end |
#delete_field(params = {}) ⇒ Struct
Deletes a field from a cases template.
After a field is deleted:
-
You can still retrieve the field by calling ‘BatchGetField`.
-
You cannot update a deleted field by calling ‘UpdateField`; it throws a `ValidationException`.
-
Deleted fields are not included in the ‘ListFields` response.
-
Calling ‘CreateCase` with a deleted field throws a `ValidationException` denoting which field identifiers in the request have been deleted.
-
Calling ‘GetCase` with a deleted field identifier returns the deleted field’s value if one exists.
-
Calling ‘UpdateCase` with a deleted field ID throws a `ValidationException` if the case does not already contain a value for the deleted field. Otherwise it succeeds, allowing you to update or remove (using `emptyValue: {}`) the field’s value from the case.
-
‘GetTemplate` does not return field IDs for deleted fields.
-
‘GetLayout` does not return field IDs for deleted fields.
-
Calling ‘SearchCases` with the deleted field ID as a filter returns any cases that have a value for the deleted field that matches the filter criteria.
-
Calling ‘SearchCases` with a `searchTerm` value that matches a deleted field’s value on a case returns the case in the response.
-
Calling ‘BatchPutFieldOptions` with a deleted field ID throw a `ValidationException`.
-
Calling ‘GetCaseEventConfiguration` does not return field IDs for deleted fields.
1518 1519 1520 1521 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1518 def delete_field(params = {}, = {}) req = build_request(:delete_field, params) req.send_request() end |
#delete_layout(params = {}) ⇒ Struct
Deletes a layout from a cases template. You can delete up to 100 layouts per domain.
After a layout is deleted:
-
You can still retrieve the layout by calling ‘GetLayout`.
-
You cannot update a deleted layout by calling ‘UpdateLayout`; it throws a `ValidationException`.
-
Deleted layouts are not included in the ‘ListLayouts` response.
1554 1555 1556 1557 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1554 def delete_layout(params = {}, = {}) req = build_request(:delete_layout, params) req.send_request() end |
#delete_related_item(params = {}) ⇒ Struct
Deletes the related item resource under a case.
<note markdown=“1”> This API cannot be used on a FILE type related attachment. To delete this type of file, use the [DeleteAttachedFile] API
</note>
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DeleteAttachedFile.html
1593 1594 1595 1596 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1593 def (params = {}, = {}) req = build_request(:delete_related_item, params) req.send_request() end |
#delete_template(params = {}) ⇒ Struct
Deletes a cases template. You can delete up to 100 templates per domain.
After a cases template is deleted:
-
You can still retrieve the template by calling ‘GetTemplate`.
-
You cannot update the template.
-
You cannot create a case by using the deleted template.
-
Deleted templates are not included in the ‘ListTemplates` response.
1630 1631 1632 1633 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1630 def delete_template(params = {}, = {}) req = build_request(:delete_template, params) req.send_request() end |
#get_case(params = {}) ⇒ Types::GetCaseResponse
Returns information about a specific case if it exists.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1690 1691 1692 1693 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1690 def get_case(params = {}, = {}) req = build_request(:get_case, params) req.send_request() end |
#get_case_audit_events(params = {}) ⇒ Types::GetCaseAuditEventsResponse
Returns the audit history about a specific case if it exists.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1754 1755 1756 1757 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1754 def get_case_audit_events(params = {}, = {}) req = build_request(:get_case_audit_events, params) req.send_request() end |
#get_case_event_configuration(params = {}) ⇒ Types::GetCaseEventConfigurationResponse
Returns the case event publishing configuration.
1785 1786 1787 1788 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1785 def get_case_event_configuration(params = {}, = {}) req = build_request(:get_case_event_configuration, params) req.send_request() end |
#get_domain(params = {}) ⇒ Types::GetDomainResponse
Returns information about a specific domain if it exists.
1824 1825 1826 1827 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1824 def get_domain(params = {}, = {}) req = build_request(:get_domain, params) req.send_request() end |
#get_layout(params = {}) ⇒ Types::GetLayoutResponse
Returns the details for the requested layout.
1878 1879 1880 1881 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1878 def get_layout(params = {}, = {}) req = build_request(:get_layout, params) req.send_request() end |
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Returns the details for the requested template. Other template APIs are:
- CreateTemplate][1
- DeleteTemplate][2
- ListTemplates][3
- UpdateTemplate][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_CreateTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_ListTemplates.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_UpdateTemplate.html
1957 1958 1959 1960 |
# File 'lib/aws-sdk-connectcases/client.rb', line 1957 def get_template(params = {}, = {}) req = build_request(:get_template, params) req.send_request() end |
#list_case_rules(params = {}) ⇒ Types::ListCaseRulesResponse
Lists all case rules in a Cases domain. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2011 2012 2013 2014 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2011 def list_case_rules(params = {}, = {}) req = build_request(:list_case_rules, params) req.send_request() end |
#list_cases_for_contact(params = {}) ⇒ Types::ListCasesForContactResponse
Lists cases for a given contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2059 2060 2061 2062 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2059 def list_cases_for_contact(params = {}, = {}) req = build_request(:list_cases_for_contact, params) req.send_request() end |
#list_domains(params = {}) ⇒ Types::ListDomainsResponse
Lists all cases domains in the Amazon Web Services account. Each list item is a condensed summary object of the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2101 2102 2103 2104 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2101 def list_domains(params = {}, = {}) req = build_request(:list_domains, params) req.send_request() end |
#list_field_options(params = {}) ⇒ Types::ListFieldOptionsResponse
Lists all of the field options for a field identifier in the domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2154 2155 2156 2157 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2154 def (params = {}, = {}) req = build_request(:list_field_options, params) req.send_request() end |
#list_fields(params = {}) ⇒ Types::ListFieldsResponse
Lists all fields in a Cases domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2202 2203 2204 2205 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2202 def list_fields(params = {}, = {}) req = build_request(:list_fields, params) req.send_request() end |
#list_layouts(params = {}) ⇒ Types::ListLayoutsResponse
Lists all layouts in the given cases domain. Each list item is a condensed summary object of the layout.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2248 2249 2250 2251 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2248 def list_layouts(params = {}, = {}) req = build_request(:list_layouts, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists tags for a resource.
2277 2278 2279 2280 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2277 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists all of the templates in a Cases domain. Each list item is a condensed summary object of the template.
Other template APIs are:
- CreateTemplate][1
- DeleteTemplate][2
- GetTemplate][3
- UpdateTemplate][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_CreateTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetTemplate.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_UpdateTemplate.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2349 2350 2351 2352 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2349 def list_templates(params = {}, = {}) req = build_request(:list_templates, params) req.send_request() end |
#put_case_event_configuration(params = {}) ⇒ Struct
Adds case event publishing configuration. For a complete list of fields you can add to the event message, see [Create case fields] in the *Amazon Connect Administrator Guide*
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-fields.html
2396 2397 2398 2399 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2396 def put_case_event_configuration(params = {}, = {}) req = build_request(:put_case_event_configuration, params) req.send_request() end |
#search_all_related_items(params = {}) ⇒ Types::SearchAllRelatedItemsResponse
Searches for related items across all cases within a domain. This is a global search operation that returns related items from multiple cases, unlike the case-specific [SearchRelatedItems] API.
**Use cases**
Following are common uses cases for this API:
-
Find cases with similar issues across the domain. For example, search for all cases containing comments about “product defect” to identify patterns and existing solutions.
-
Locate all cases associated with specific contacts or orders. For example, find all cases linked to a contactArn to understand the complete customer journey.
-
Monitor SLA compliance across cases. For example, search for all cases with “Active” SLA status to prioritize remediation efforts.
**Important things to know**
-
This API returns case identifiers, not complete case objects. To retrieve full case details, you must make additional calls to the
- GetCase][2
-
API for each returned case ID.
-
This API searches across related items content, not case fields. Use the [SearchCases] API to search within case field values.
Endpoints: See [Amazon Connect endpoints and quotas].
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_SearchRelatedItems.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetCase.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_SearchCases.html [4]: docs.aws.amazon.com/general/latest/gr/connect_region.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2627 2628 2629 2630 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2627 def (params = {}, = {}) req = build_request(:search_all_related_items, params) req.send_request() end |
#search_cases(params = {}) ⇒ Types::SearchCasesResponse
Searches for cases within their associated Cases domain. Search results are returned as a paginated list of abridged case documents.
<note markdown=“1”> For ‘customer_id` you must provide the full customer profile ARN in this format: ` arn:aws:profile:your AWS Region:your AWS account ID:domains/profiles domain name/profiles/profile ID`.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2803 2804 2805 2806 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2803 def search_cases(params = {}, = {}) req = build_request(:search_cases, params) req.send_request() end |
#search_related_items(params = {}) ⇒ Types::SearchRelatedItemsResponse
Searches for related items that are associated with a case.
<note markdown=“1”> If no filters are provided, this returns all related items associated with a case.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2994 2995 2996 2997 |
# File 'lib/aws-sdk-connectcases/client.rb', line 2994 def (params = {}, = {}) req = build_request(:search_related_items, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a resource.
3023 3024 3025 3026 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3023 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Untags a resource.
3049 3050 3051 3052 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3049 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_case(params = {}) ⇒ Struct
<note markdown=“1”> If you provide a value for ‘PerformedBy.UserArn` you must also have
- connect:DescribeUser][1
-
permission on the User ARN resource that you
provide
</note>
Updates the values of fields on a case. Fields to be updated are
received as an array of id/value pairs identical to the ‘CreateCase` input .
If the action is successful, the service sends back an HTTP 200
response with an empty HTTP body.
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html
3115 3116 3117 3118 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3115 def update_case(params = {}, = {}) req = build_request(:update_case, params) req.send_request() end |
#update_case_rule(params = {}) ⇒ Struct
Updates a case rule. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
3257 3258 3259 3260 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3257 def update_case_rule(params = {}, = {}) req = build_request(:update_case_rule, params) req.send_request() end |
#update_field(params = {}) ⇒ Struct
Updates the properties of an existing field.
3299 3300 3301 3302 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3299 def update_field(params = {}, = {}) req = build_request(:update_field, params) req.send_request() end |
#update_layout(params = {}) ⇒ Struct
Updates the attributes of an existing layout.
If the action is successful, the service sends back an HTTP 200 response with an empty HTTP body.
A ‘ValidationException` is returned when you add non-existent `fieldIds` to a layout.
<note markdown=“1”> Title and Status fields cannot be part of layouts because they are not configurable.
</note>
3376 3377 3378 3379 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3376 def update_layout(params = {}, = {}) req = build_request(:update_layout, params) req.send_request() end |
#update_related_item(params = {}) ⇒ Types::UpdateRelatedItemResponse
Updates the content of a related item associated with a case. The following related item types are supported:
-
Comment - Update the text content of an existing comment
-
Custom - Update the fields of a custom related item. You can add, modify, and remove fields from a custom related item. There’s a quota for the number of fields allowed in a Custom type related item. See [Amazon Connect Cases quotas].
**Important things to know**
-
When updating a Custom related item, all existing and new fields, and their associated values should be included in the request. Fields not included as part of this request will be removed.
-
If you provide a value for ‘performedBy.userArn` you must also have
- DescribeUser][2
-
permission on the ARN of the user that you
provide.
- System case fields][3
-
cannot be used in a custom related item.
Endpoints: See [Amazon Connect endpoints and quotas].
[1]: docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html#cases-quotas [2]: docs.aws.amazon.com/connect/latest/APIReference/API_DescribeUser.html [3]: docs.aws.amazon.com/connect/latest/adminguide/case-fields.html#system-case-fields [4]: docs.aws.amazon.com/general/latest/gr/connect_region.html
3512 3513 3514 3515 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3512 def (params = {}, = {}) req = build_request(:update_related_item, params) req.send_request() end |
#update_template(params = {}) ⇒ Struct
Updates the attributes of an existing template. The template attributes that can be modified include ‘name`, `description`, `layoutConfiguration`, `requiredFields`, and `status`. At least one of these attributes must not be null. If a null value is provided for a given attribute, that attribute is ignored and its current value is preserved.
Other template APIs are:
- CreateTemplate][1
- DeleteTemplate][2
- GetTemplate][3
- ListTemplates][4
[1]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_CreateTemplate.html [2]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_DeleteTemplate.html [3]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_GetTemplate.html [4]: docs.aws.amazon.com/connect/latest/APIReference/API_connect-cases_ListTemplates.html
3614 3615 3616 3617 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3614 def update_template(params = {}, = {}) req = build_request(:update_template, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3643 3644 3645 |
# File 'lib/aws-sdk-connectcases/client.rb', line 3643 def waiter_names [] end |