Class: Aws::ConnectCases::Types::CompoundCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::CompoundCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
A compound condition that combines multiple boolean conditions using logical operators. In the Amazon Connect admin website, case rules are known as *case field conditions*. For more information about case field conditions, see [Add case field conditions to a case template].
[1]: docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Types::BooleanCondition>
The list of conditions to combine using the logical operator.
Instance Attribute Details
#conditions ⇒ Array<Types::BooleanCondition>
The list of conditions to combine using the logical operator.
619 620 621 622 623 |
# File 'lib/aws-sdk-connectcases/types.rb', line 619 class CompoundCondition < Struct.new( :conditions) SENSITIVE = [] include Aws::Structure end |