Class: Aws::ConnectCases::Types::FieldAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::FieldAttributes
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Note:
FieldAttributes is a union - when making an API calls you must set exactly one of the members.
Note:
FieldAttributes is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FieldAttributes corresponding to the set member.
Union of field attributes.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#text ⇒ Types::TextAttributes
Field attributes for Text field type.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#text ⇒ Types::TextAttributes
Field attributes for Text field type.
1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1433 class FieldAttributes < Struct.new( :text, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < FieldAttributes; end class Unknown < FieldAttributes; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1433 1434 1435 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1433 def unknown @unknown end |