Class: Aws::ConnectCases::Types::GetCaseAuditEventsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::GetCaseAuditEventsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#case_id ⇒ String
A unique identifier of the case.
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#max_results ⇒ Integer
The maximum number of audit events to return.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#case_id ⇒ String
A unique identifier of the case.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1849 class GetCaseAuditEventsRequest < Struct.new( :case_id, :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#domain_id ⇒ String
The unique identifier of the Cases domain.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1849 class GetCaseAuditEventsRequest < Struct.new( :case_id, :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of audit events to return. When no value is provided, 25 is the default.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1849 class GetCaseAuditEventsRequest < Struct.new( :case_id, :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
1849 1850 1851 1852 1853 1854 1855 1856 |
# File 'lib/aws-sdk-connectcases/types.rb', line 1849 class GetCaseAuditEventsRequest < Struct.new( :case_id, :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |