Class: Aws::ConnectCases::Types::ListCaseRulesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ListCaseRulesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
Unique identifier of a Cases domain.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
Instance Attribute Details
#domain_id ⇒ String
Unique identifier of a Cases domain.
2389 2390 2391 2392 2393 2394 2395 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2389 class ListCaseRulesRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
2389 2390 2391 2392 2393 2394 2395 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2389 class ListCaseRulesRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
2389 2390 2391 2392 2393 2394 2395 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2389 class ListCaseRulesRequest < Struct.new( :domain_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |