Class: Aws::ConnectCases::Types::ListFieldOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ListFieldOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#field_id ⇒ String
The unique identifier of a field.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#values ⇒ Array<String>
A list of
FieldOptionvalues to filter on forListFieldOptions.
Instance Attribute Details
#domain_id ⇒ String
The unique identifier of the Cases domain.
2568 2569 2570 2571 2572 2573 2574 2575 2576 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2568 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#field_id ⇒ String
The unique identifier of a field.
2568 2569 2570 2571 2572 2573 2574 2575 2576 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2568 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
2568 2569 2570 2571 2572 2573 2574 2575 2576 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2568 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
2568 2569 2570 2571 2572 2573 2574 2575 2576 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2568 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
A list of FieldOption values to filter on for ListFieldOptions.
2568 2569 2570 2571 2572 2573 2574 2575 2576 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2568 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |