Class: Aws::ConnectCases::Types::ListFieldOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ConnectCases::Types::ListFieldOptionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-connectcases/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_id ⇒ String
The unique identifier of the Cases domain.
-
#field_id ⇒ String
The unique identifier of a field.
-
#max_results ⇒ Integer
The maximum number of results to return per page.
-
#next_token ⇒ String
The token for the next set of results.
-
#values ⇒ Array<String>
A list of
FieldOptionvalues to filter on forListFieldOptions.
Instance Attribute Details
#domain_id ⇒ String
The unique identifier of the Cases domain.
2523 2524 2525 2526 2527 2528 2529 2530 2531 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2523 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#field_id ⇒ String
The unique identifier of a field.
2523 2524 2525 2526 2527 2528 2529 2530 2531 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2523 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return per page.
2523 2524 2525 2526 2527 2528 2529 2530 2531 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2523 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
2523 2524 2525 2526 2527 2528 2529 2530 2531 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2523 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
A list of FieldOption values to filter on for ListFieldOptions.
2523 2524 2525 2526 2527 2528 2529 2530 2531 |
# File 'lib/aws-sdk-connectcases/types.rb', line 2523 class ListFieldOptionsRequest < Struct.new( :domain_id, :field_id, :max_results, :next_token, :values) SENSITIVE = [] include Aws::Structure end |